my %hash;
  $hash{simple_smile} = "\x{1F642}";
if ($] >= 5.012 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"airplane"} = "\x{2708}\x{FE0F}";
  $hash{"alembic"} = "\x{2697}\x{FE0F}";
  $hash{"anchor"} = "\x{2693}";
  $hash{"aquarius"} = "\x{2652}";
  $hash{"aries"} = "\x{2648}";
  $hash{"arrow_backward"} = "\x{25C0}\x{FE0F}";
  $hash{"arrow_down"} = "\x{2B07}\x{FE0F}";
  $hash{"arrow_forward"} = "\x{25B6}\x{FE0F}";
  $hash{"arrow_heading_down"} = "\x{2935}\x{FE0F}";
  $hash{"arrow_heading_up"} = "\x{2934}\x{FE0F}";
  $hash{"arrow_left"} = "\x{2B05}\x{FE0F}";
  $hash{"arrow_lower_left"} = "\x{2199}\x{FE0F}";
  $hash{"arrow_lower_right"} = "\x{2198}\x{FE0F}";
  $hash{"arrow_right"} = "\x{27A1}\x{FE0F}";
  $hash{"arrow_right_hook"} = "\x{21AA}\x{FE0F}";
  $hash{"arrow_up"} = "\x{2B06}\x{FE0F}";
  $hash{"arrow_up_down"} = "\x{2195}\x{FE0F}";
  $hash{"arrow_upper_left"} = "\x{2196}\x{FE0F}";
  $hash{"arrow_upper_right"} = "\x{2197}\x{FE0F}";
  $hash{"atom_symbol"} = "\x{269B}\x{FE0F}";
  $hash{"ballot_box_with_check"} = "\x{2611}\x{FE0F}";
  $hash{"bangbang"} = "\x{203C}\x{FE0F}";
  $hash{"baseball"} = "\x{26BE}";
  $hash{"biohazard_sign"} = "\x{2623}\x{FE0F}";
  $hash{"black_circle"} = "\x{26AB}";
  $hash{"black_large_square"} = "\x{2B1B}";
  $hash{"black_medium_small_square"} = "\x{25FE}";
  $hash{"black_medium_square"} = "\x{25FC}\x{FE0F}";
  $hash{"black_nib"} = "\x{2712}\x{FE0F}";
  $hash{"black_small_square"} = "\x{25AA}\x{FE0F}";
  $hash{"boat"} = "\x{26F5}";
  $hash{"cancer"} = "\x{264B}";
  $hash{"capricorn"} = "\x{2651}";
  $hash{"chains"} = "\x{26D3}\x{FE0F}";
  $hash{"church"} = "\x{26EA}";
  $hash{"cloud"} = "\x{2601}\x{FE0F}";
  $hash{"clubs"} = "\x{2663}\x{FE0F}";
  $hash{"coffee"} = "\x{2615}";
  $hash{"coffin"} = "\x{26B0}\x{FE0F}";
  $hash{"comet"} = "\x{2604}\x{FE0F}";
  $hash{"congratulations"} = "\x{3297}\x{FE0F}";
  $hash{"copyright"} = "\x{00A9}\x{FE0F}";
  $hash{"crossed_swords"} = "\x{2694}\x{FE0F}";
  $hash{"diamonds"} = "\x{2666}\x{FE0F}";
  $hash{"eight"} = "\x{0038}\x{FE0F}\x{20E3}";
  $hash{"eight_pointed_black_star"} = "\x{2734}\x{FE0F}";
  $hash{"eight_spoked_asterisk"} = "\x{2733}\x{FE0F}";
  $hash{"eject"} = "\x{23CF}\x{FE0F}";
  $hash{"email"} = "\x{2709}\x{FE0F}";
  $hash{"envelope"} = "\x{2709}\x{FE0F}";
  $hash{"exclamation"} = "\x{2757}";
  $hash{"female_sign"} = "\x{2640}\x{FE0F}";
  $hash{"ferry"} = "\x{26F4}\x{FE0F}";
  $hash{"five"} = "\x{0035}\x{FE0F}\x{20E3}";
  $hash{"fleur_de_lis"} = "\x{269C}\x{FE0F}";
  $hash{"fountain"} = "\x{26F2}";
  $hash{"four"} = "\x{0034}\x{FE0F}\x{20E3}";
  $hash{"fuelpump"} = "\x{26FD}";
  $hash{"funeral_urn"} = "\x{26B1}\x{FE0F}";
  $hash{"gear"} = "\x{2699}\x{FE0F}";
  $hash{"gemini"} = "\x{264A}";
  $hash{"golf"} = "\x{26F3}";
  $hash{"hammer_and_pick"} = "\x{2692}\x{FE0F}";
  $hash{"hash"} = "\x{0023}\x{FE0F}\x{20E3}";
  $hash{"heart"} = "\x{2764}\x{FE0F}";
  $hash{"hearts"} = "\x{2665}\x{FE0F}";
  $hash{"heavy_check_mark"} = "\x{2714}\x{FE0F}";
  $hash{"heavy_exclamation_mark"} = "\x{2757}";
  $hash{"heavy_heart_exclamation_mark_ornament"} = "\x{2763}\x{FE0F}";
  $hash{"heavy_multiplication_x"} = "\x{2716}\x{FE0F}";
  $hash{"helmet_with_white_cross"} = "\x{26D1}\x{FE0F}";
  $hash{"hotsprings"} = "\x{2668}\x{FE0F}";
  $hash{"hourglass"} = "\x{231B}";
  $hash{"ice_skate"} = "\x{26F8}\x{FE0F}";
  $hash{"information_source"} = "\x{2139}\x{FE0F}";
  $hash{"interrobang"} = "\x{2049}\x{FE0F}";
  $hash{"keyboard"} = "\x{2328}\x{FE0F}";
  $hash{"keycap_star"} = "\x{002A}\x{FE0F}\x{20E3}";
  $hash{"latin_cross"} = "\x{271D}\x{FE0F}";
  $hash{"left_right_arrow"} = "\x{2194}\x{FE0F}";
  $hash{"leftwards_arrow_with_hook"} = "\x{21A9}\x{FE0F}";
  $hash{"leo"} = "\x{264C}";
  $hash{"libra"} = "\x{264E}";
  $hash{"m"} = "\x{24C2}\x{FE0F}";
  $hash{"mahjong"} = "\x{1F004}";
  $hash{"male_sign"} = "\x{2642}\x{FE0F}";
  $hash{"man-bouncing-ball"} = "\x{26F9}\x{FE0F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"medical_symbol"} = "\x{2695}\x{FE0F}";
  $hash{"mountain"} = "\x{26F0}\x{FE0F}";
  $hash{"nine"} = "\x{0039}\x{FE0F}\x{20E3}";
  $hash{"no_entry"} = "\x{26D4}";
  $hash{"o"} = "\x{2B55}";
  $hash{"one"} = "\x{0031}\x{FE0F}\x{20E3}";
  $hash{"orthodox_cross"} = "\x{2626}\x{FE0F}";
  $hash{"parking"} = "\x{1F17F}\x{FE0F}";
  $hash{"part_alternation_mark"} = "\x{303D}\x{FE0F}";
  $hash{"partly_sunny"} = "\x{26C5}";
  $hash{"peace_symbol"} = "\x{262E}\x{FE0F}";
  $hash{"pencil2"} = "\x{270F}\x{FE0F}";
  $hash{"person_with_ball"} = "\x{26F9}\x{FE0F}";
  $hash{"phone"} = "\x{260E}\x{FE0F}";
  $hash{"pick"} = "\x{26CF}\x{FE0F}";
  $hash{"pisces"} = "\x{2653}";
  $hash{"point_up"} = "\x{261D}\x{FE0F}";
  $hash{"radioactive_sign"} = "\x{2622}\x{FE0F}";
  $hash{"recycle"} = "\x{267B}\x{FE0F}";
  $hash{"registered"} = "\x{00AE}\x{FE0F}";
  $hash{"relaxed"} = "\x{263A}\x{FE0F}";
  $hash{"sagittarius"} = "\x{2650}";
  $hash{"sailboat"} = "\x{26F5}";
  $hash{"scales"} = "\x{2696}\x{FE0F}";
  $hash{"scissors"} = "\x{2702}\x{FE0F}";
  $hash{"scorpius"} = "\x{264F}";
  $hash{"secret"} = "\x{3299}\x{FE0F}";
  $hash{"seven"} = "\x{0037}\x{FE0F}\x{20E3}";
  $hash{"shamrock"} = "\x{2618}\x{FE0F}";
  $hash{"shinto_shrine"} = "\x{26E9}\x{FE0F}";
  $hash{"six"} = "\x{0036}\x{FE0F}\x{20E3}";
  $hash{"skier"} = "\x{26F7}\x{FE0F}";
  $hash{"skull_and_crossbones"} = "\x{2620}\x{FE0F}";
  $hash{"snowflake"} = "\x{2744}\x{FE0F}";
  $hash{"snowman"} = "\x{2603}\x{FE0F}";
  $hash{"snowman_without_snow"} = "\x{26C4}";
  $hash{"soccer"} = "\x{26BD}";
  $hash{"spades"} = "\x{2660}\x{FE0F}";
  $hash{"sparkle"} = "\x{2747}\x{FE0F}";
  $hash{"staff_of_aesculapius"} = "\x{2695}\x{FE0F}";
  $hash{"star"} = "\x{2B50}";
  $hash{"star_and_crescent"} = "\x{262A}\x{FE0F}";
  $hash{"star_of_david"} = "\x{2721}\x{FE0F}";
  $hash{"sunny"} = "\x{2600}\x{FE0F}";
  $hash{"taurus"} = "\x{2649}";
  $hash{"telephone"} = "\x{260E}\x{FE0F}";
  $hash{"tent"} = "\x{26FA}";
  $hash{"three"} = "\x{0033}\x{FE0F}\x{20E3}";
  $hash{"thunder_cloud_and_rain"} = "\x{26C8}\x{FE0F}";
  $hash{"tm"} = "\x{2122}\x{FE0F}";
  $hash{"two"} = "\x{0032}\x{FE0F}\x{20E3}";
  $hash{"u6307"} = "\x{1F22F}";
  $hash{"u7121"} = "\x{1F21A}";
  $hash{"umbrella"} = "\x{2602}\x{FE0F}";
  $hash{"umbrella_on_ground"} = "\x{26F1}\x{FE0F}";
  $hash{"umbrella_with_rain_drops"} = "\x{2614}";
  $hash{"v"} = "\x{270C}\x{FE0F}";
  $hash{"virgo"} = "\x{264D}";
  $hash{"warning"} = "\x{26A0}\x{FE0F}";
  $hash{"watch"} = "\x{231A}";
  $hash{"wavy_dash"} = "\x{3030}\x{FE0F}";
  $hash{"wheel_of_dharma"} = "\x{2638}\x{FE0F}";
  $hash{"wheelchair"} = "\x{267F}";
  $hash{"white_circle"} = "\x{26AA}";
  $hash{"white_frowning_face"} = "\x{2639}\x{FE0F}";
  $hash{"white_large_square"} = "\x{2B1C}";
  $hash{"white_medium_small_square"} = "\x{25FD}";
  $hash{"white_medium_square"} = "\x{25FB}\x{FE0F}";
  $hash{"white_small_square"} = "\x{25AB}\x{FE0F}";
  $hash{"woman-bouncing-ball"} = "\x{26F9}\x{FE0F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"writing_hand"} = "\x{270D}\x{FE0F}";
  $hash{"yin_yang"} = "\x{262F}\x{FE0F}";
  $hash{"zap"} = "\x{26A1}";
  $hash{"zero"} = "\x{0030}\x{FE0F}\x{20E3}";
}
if ($] >= 5.014 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"+1"} = "\x{1F44D}";
  $hash{"-1"} = "\x{1F44E}";
  $hash{"100"} = "\x{1F4AF}";
  $hash{"1234"} = "\x{1F522}";
  $hash{"8ball"} = "\x{1F3B1}";
  $hash{"a"} = "\x{1F170}\x{FE0F}";
  $hash{"ab"} = "\x{1F18E}";
  $hash{"abc"} = "\x{1F524}";
  $hash{"abcd"} = "\x{1F521}";
  $hash{"accept"} = "\x{1F251}";
  $hash{"aerial_tramway"} = "\x{1F6A1}";
  $hash{"alarm_clock"} = "\x{23F0}";
  $hash{"alien"} = "\x{1F47D}";
  $hash{"ambulance"} = "\x{1F691}";
  $hash{"angel"} = "\x{1F47C}";
  $hash{"anger"} = "\x{1F4A2}";
  $hash{"angry"} = "\x{1F620}";
  $hash{"ant"} = "\x{1F41C}";
  $hash{"apple"} = "\x{1F34E}";
  $hash{"arrow_double_down"} = "\x{23EC}";
  $hash{"arrow_double_up"} = "\x{23EB}";
  $hash{"arrow_down_small"} = "\x{1F53D}";
  $hash{"arrow_up_small"} = "\x{1F53C}";
  $hash{"arrows_clockwise"} = "\x{1F503}";
  $hash{"arrows_counterclockwise"} = "\x{1F504}";
  $hash{"art"} = "\x{1F3A8}";
  $hash{"articulated_lorry"} = "\x{1F69B}";
  $hash{"astonished"} = "\x{1F632}";
  $hash{"athletic_shoe"} = "\x{1F45F}";
  $hash{"atm"} = "\x{1F3E7}";
  $hash{"b"} = "\x{1F171}\x{FE0F}";
  $hash{"baby"} = "\x{1F476}";
  $hash{"baby_bottle"} = "\x{1F37C}";
  $hash{"baby_chick"} = "\x{1F424}";
  $hash{"baby_symbol"} = "\x{1F6BC}";
  $hash{"back"} = "\x{1F519}";
  $hash{"baggage_claim"} = "\x{1F6C4}";
  $hash{"balloon"} = "\x{1F388}";
  $hash{"bamboo"} = "\x{1F38D}";
  $hash{"banana"} = "\x{1F34C}";
  $hash{"bank"} = "\x{1F3E6}";
  $hash{"bar_chart"} = "\x{1F4CA}";
  $hash{"barber"} = "\x{1F488}";
  $hash{"basketball"} = "\x{1F3C0}";
  $hash{"bath"} = "\x{1F6C0}";
  $hash{"bathtub"} = "\x{1F6C1}";
  $hash{"battery"} = "\x{1F50B}";
  $hash{"bear"} = "\x{1F43B}";
  $hash{"bee"} = "\x{1F41D}";
  $hash{"beer"} = "\x{1F37A}";
  $hash{"beers"} = "\x{1F37B}";
  $hash{"beginner"} = "\x{1F530}";
  $hash{"bell"} = "\x{1F514}";
  $hash{"bento"} = "\x{1F371}";
  $hash{"bicyclist"} = "\x{1F6B4}";
  $hash{"bike"} = "\x{1F6B2}";
  $hash{"bikini"} = "\x{1F459}";
  $hash{"bird"} = "\x{1F426}";
  $hash{"birthday"} = "\x{1F382}";
  $hash{"black_joker"} = "\x{1F0CF}";
  $hash{"black_left_pointing_double_triangle_with_vertical_bar"} = "\x{23EE}\x{FE0F}";
  $hash{"black_right_pointing_double_triangle_with_vertical_bar"} = "\x{23ED}\x{FE0F}";
  $hash{"black_right_pointing_triangle_with_double_vertical_bar"} = "\x{23EF}\x{FE0F}";
  $hash{"black_square_button"} = "\x{1F532}";
  $hash{"blond-haired-man"} = "\x{1F471}\x{200D}\x{2642}\x{FE0F}";
  $hash{"blond-haired-woman"} = "\x{1F471}\x{200D}\x{2640}\x{FE0F}";
  $hash{"blossom"} = "\x{1F33C}";
  $hash{"blowfish"} = "\x{1F421}";
  $hash{"blue_book"} = "\x{1F4D8}";
  $hash{"blue_car"} = "\x{1F699}";
  $hash{"blue_heart"} = "\x{1F499}";
  $hash{"blush"} = "\x{1F60A}";
  $hash{"boar"} = "\x{1F417}";
  $hash{"bomb"} = "\x{1F4A3}";
  $hash{"book"} = "\x{1F4D6}";
  $hash{"bookmark"} = "\x{1F516}";
  $hash{"bookmark_tabs"} = "\x{1F4D1}";
  $hash{"books"} = "\x{1F4DA}";
  $hash{"boom"} = "\x{1F4A5}";
  $hash{"boot"} = "\x{1F462}";
  $hash{"bouquet"} = "\x{1F490}";
  $hash{"bow"} = "\x{1F647}";
  $hash{"bowling"} = "\x{1F3B3}";
  $hash{"boy"} = "\x{1F466}";
  $hash{"bread"} = "\x{1F35E}";
  $hash{"bride_with_veil"} = "\x{1F470}";
  $hash{"bridge_at_night"} = "\x{1F309}";
  $hash{"briefcase"} = "\x{1F4BC}";
  $hash{"broken_heart"} = "\x{1F494}";
  $hash{"bug"} = "\x{1F41B}";
  $hash{"bulb"} = "\x{1F4A1}";
  $hash{"bullettrain_front"} = "\x{1F685}";
  $hash{"bullettrain_side"} = "\x{1F684}";
  $hash{"bus"} = "\x{1F68C}";
  $hash{"busstop"} = "\x{1F68F}";
  $hash{"bust_in_silhouette"} = "\x{1F464}";
  $hash{"busts_in_silhouette"} = "\x{1F465}";
  $hash{"cactus"} = "\x{1F335}";
  $hash{"cake"} = "\x{1F370}";
  $hash{"calendar"} = "\x{1F4C6}";
  $hash{"calling"} = "\x{1F4F2}";
  $hash{"camel"} = "\x{1F42B}";
  $hash{"camera"} = "\x{1F4F7}";
  $hash{"candy"} = "\x{1F36C}";
  $hash{"capital_abcd"} = "\x{1F520}";
  $hash{"car"} = "\x{1F697}";
  $hash{"card_index"} = "\x{1F4C7}";
  $hash{"carousel_horse"} = "\x{1F3A0}";
  $hash{"cat"} = "\x{1F431}";
  $hash{"cat2"} = "\x{1F408}";
  $hash{"cd"} = "\x{1F4BF}";
  $hash{"chart"} = "\x{1F4B9}";
  $hash{"chart_with_downwards_trend"} = "\x{1F4C9}";
  $hash{"chart_with_upwards_trend"} = "\x{1F4C8}";
  $hash{"checkered_flag"} = "\x{1F3C1}";
  $hash{"cherries"} = "\x{1F352}";
  $hash{"cherry_blossom"} = "\x{1F338}";
  $hash{"chestnut"} = "\x{1F330}";
  $hash{"chicken"} = "\x{1F414}";
  $hash{"children_crossing"} = "\x{1F6B8}";
  $hash{"chocolate_bar"} = "\x{1F36B}";
  $hash{"christmas_tree"} = "\x{1F384}";
  $hash{"cinema"} = "\x{1F3A6}";
  $hash{"circus_tent"} = "\x{1F3AA}";
  $hash{"city_sunrise"} = "\x{1F307}";
  $hash{"city_sunset"} = "\x{1F306}";
  $hash{"cl"} = "\x{1F191}";
  $hash{"clap"} = "\x{1F44F}";
  $hash{"clapper"} = "\x{1F3AC}";
  $hash{"clipboard"} = "\x{1F4CB}";
  $hash{"clock1"} = "\x{1F550}";
  $hash{"clock10"} = "\x{1F559}";
  $hash{"clock1030"} = "\x{1F565}";
  $hash{"clock11"} = "\x{1F55A}";
  $hash{"clock1130"} = "\x{1F566}";
  $hash{"clock12"} = "\x{1F55B}";
  $hash{"clock1230"} = "\x{1F567}";
  $hash{"clock130"} = "\x{1F55C}";
  $hash{"clock2"} = "\x{1F551}";
  $hash{"clock230"} = "\x{1F55D}";
  $hash{"clock3"} = "\x{1F552}";
  $hash{"clock330"} = "\x{1F55E}";
  $hash{"clock4"} = "\x{1F553}";
  $hash{"clock430"} = "\x{1F55F}";
  $hash{"clock5"} = "\x{1F554}";
  $hash{"clock530"} = "\x{1F560}";
  $hash{"clock6"} = "\x{1F555}";
  $hash{"clock630"} = "\x{1F561}";
  $hash{"clock7"} = "\x{1F556}";
  $hash{"clock730"} = "\x{1F562}";
  $hash{"clock8"} = "\x{1F557}";
  $hash{"clock830"} = "\x{1F563}";
  $hash{"clock9"} = "\x{1F558}";
  $hash{"clock930"} = "\x{1F564}";
  $hash{"closed_book"} = "\x{1F4D5}";
  $hash{"closed_lock_with_key"} = "\x{1F510}";
  $hash{"closed_umbrella"} = "\x{1F302}";
  $hash{"cn"} = "\x{1F1E8}\x{1F1F3}";
  $hash{"cocktail"} = "\x{1F378}";
  $hash{"cold_sweat"} = "\x{1F630}";
  $hash{"collision"} = "\x{1F4A5}";
  $hash{"computer"} = "\x{1F4BB}";
  $hash{"confetti_ball"} = "\x{1F38A}";
  $hash{"confounded"} = "\x{1F616}";
  $hash{"construction"} = "\x{1F6A7}";
  $hash{"construction_worker"} = "\x{1F477}";
  $hash{"convenience_store"} = "\x{1F3EA}";
  $hash{"cookie"} = "\x{1F36A}";
  $hash{"cooking"} = "\x{1F373}";
  $hash{"cool"} = "\x{1F192}";
  $hash{"cop"} = "\x{1F46E}";
  $hash{"corn"} = "\x{1F33D}";
  $hash{"couple"} = "\x{1F46B}";
  $hash{"couple_with_heart"} = "\x{1F491}";
  $hash{"couplekiss"} = "\x{1F48F}";
  $hash{"cow"} = "\x{1F42E}";
  $hash{"cow2"} = "\x{1F404}";
  $hash{"credit_card"} = "\x{1F4B3}";
  $hash{"crescent_moon"} = "\x{1F319}";
  $hash{"crocodile"} = "\x{1F40A}";
  $hash{"crossed_flags"} = "\x{1F38C}";
  $hash{"crown"} = "\x{1F451}";
  $hash{"cry"} = "\x{1F622}";
  $hash{"crying_cat_face"} = "\x{1F63F}";
  $hash{"crystal_ball"} = "\x{1F52E}";
  $hash{"cupid"} = "\x{1F498}";
  $hash{"curly_loop"} = "\x{27B0}";
  $hash{"currency_exchange"} = "\x{1F4B1}";
  $hash{"curry"} = "\x{1F35B}";
  $hash{"custard"} = "\x{1F36E}";
  $hash{"customs"} = "\x{1F6C3}";
  $hash{"cyclone"} = "\x{1F300}";
  $hash{"dancer"} = "\x{1F483}";
  $hash{"dancers"} = "\x{1F46F}";
  $hash{"dango"} = "\x{1F361}";
  $hash{"dart"} = "\x{1F3AF}";
  $hash{"dash"} = "\x{1F4A8}";
  $hash{"date"} = "\x{1F4C5}";
  $hash{"de"} = "\x{1F1E9}\x{1F1EA}";
  $hash{"deciduous_tree"} = "\x{1F333}";
  $hash{"department_store"} = "\x{1F3EC}";
  $hash{"diamond_shape_with_a_dot_inside"} = "\x{1F4A0}";
  $hash{"disappointed"} = "\x{1F61E}";
  $hash{"disappointed_relieved"} = "\x{1F625}";
  $hash{"dizzy"} = "\x{1F4AB}";
  $hash{"dizzy_face"} = "\x{1F635}";
  $hash{"do_not_litter"} = "\x{1F6AF}";
  $hash{"dog"} = "\x{1F436}";
  $hash{"dog2"} = "\x{1F415}";
  $hash{"dollar"} = "\x{1F4B5}";
  $hash{"dolls"} = "\x{1F38E}";
  $hash{"dolphin"} = "\x{1F42C}";
  $hash{"door"} = "\x{1F6AA}";
  $hash{"doughnut"} = "\x{1F369}";
  $hash{"dragon"} = "\x{1F409}";
  $hash{"dragon_face"} = "\x{1F432}";
  $hash{"dress"} = "\x{1F457}";
  $hash{"dromedary_camel"} = "\x{1F42A}";
  $hash{"droplet"} = "\x{1F4A7}";
  $hash{"dvd"} = "\x{1F4C0}";
  $hash{"e-mail"} = "\x{1F4E7}";
  $hash{"ear"} = "\x{1F442}";
  $hash{"ear_of_rice"} = "\x{1F33E}";
  $hash{"earth_africa"} = "\x{1F30D}";
  $hash{"earth_americas"} = "\x{1F30E}";
  $hash{"earth_asia"} = "\x{1F30F}";
  $hash{"eggplant"} = "\x{1F346}";
  $hash{"electric_plug"} = "\x{1F50C}";
  $hash{"elephant"} = "\x{1F418}";
  $hash{"end"} = "\x{1F51A}";
  $hash{"envelope_with_arrow"} = "\x{1F4E9}";
  $hash{"es"} = "\x{1F1EA}\x{1F1F8}";
  $hash{"euro"} = "\x{1F4B6}";
  $hash{"european_castle"} = "\x{1F3F0}";
  $hash{"european_post_office"} = "\x{1F3E4}";
  $hash{"evergreen_tree"} = "\x{1F332}";
  $hash{"eyeglasses"} = "\x{1F453}";
  $hash{"eyes"} = "\x{1F440}";
  $hash{"facepunch"} = "\x{1F44A}";
  $hash{"factory"} = "\x{1F3ED}";
  $hash{"fallen_leaf"} = "\x{1F342}";
  $hash{"family"} = "\x{1F46A}";
  $hash{"fast_forward"} = "\x{23E9}";
  $hash{"fax"} = "\x{1F4E0}";
  $hash{"fearful"} = "\x{1F628}";
  $hash{"feet"} = "\x{1F43E}";
  $hash{"female-artist"} = "\x{1F469}\x{200D}\x{1F3A8}";
  $hash{"female-astronaut"} = "\x{1F469}\x{200D}\x{1F680}";
  $hash{"female-construction-worker"} = "\x{1F477}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female-cook"} = "\x{1F469}\x{200D}\x{1F373}";
  $hash{"female-doctor"} = "\x{1F469}\x{200D}\x{2695}\x{FE0F}";
  $hash{"female-factory-worker"} = "\x{1F469}\x{200D}\x{1F3ED}";
  $hash{"female-farmer"} = "\x{1F469}\x{200D}\x{1F33E}";
  $hash{"female-firefighter"} = "\x{1F469}\x{200D}\x{1F692}";
  $hash{"female-guard"} = "\x{1F482}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female-judge"} = "\x{1F469}\x{200D}\x{2696}\x{FE0F}";
  $hash{"female-mechanic"} = "\x{1F469}\x{200D}\x{1F527}";
  $hash{"female-office-worker"} = "\x{1F469}\x{200D}\x{1F4BC}";
  $hash{"female-pilot"} = "\x{1F469}\x{200D}\x{2708}\x{FE0F}";
  $hash{"female-police-officer"} = "\x{1F46E}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female-scientist"} = "\x{1F469}\x{200D}\x{1F52C}";
  $hash{"female-singer"} = "\x{1F469}\x{200D}\x{1F3A4}";
  $hash{"female-student"} = "\x{1F469}\x{200D}\x{1F393}";
  $hash{"female-teacher"} = "\x{1F469}\x{200D}\x{1F3EB}";
  $hash{"female-technologist"} = "\x{1F469}\x{200D}\x{1F4BB}";
  $hash{"ferris_wheel"} = "\x{1F3A1}";
  $hash{"file_folder"} = "\x{1F4C1}";
  $hash{"fire"} = "\x{1F525}";
  $hash{"fire_engine"} = "\x{1F692}";
  $hash{"fireworks"} = "\x{1F386}";
  $hash{"first_quarter_moon"} = "\x{1F313}";
  $hash{"first_quarter_moon_with_face"} = "\x{1F31B}";
  $hash{"fish"} = "\x{1F41F}";
  $hash{"fish_cake"} = "\x{1F365}";
  $hash{"fishing_pole_and_fish"} = "\x{1F3A3}";
  $hash{"fist"} = "\x{270A}";
  $hash{"flag-ac"} = "\x{1F1E6}\x{1F1E8}";
  $hash{"flag-ad"} = "\x{1F1E6}\x{1F1E9}";
  $hash{"flag-ae"} = "\x{1F1E6}\x{1F1EA}";
  $hash{"flag-af"} = "\x{1F1E6}\x{1F1EB}";
  $hash{"flag-ag"} = "\x{1F1E6}\x{1F1EC}";
  $hash{"flag-ai"} = "\x{1F1E6}\x{1F1EE}";
  $hash{"flag-al"} = "\x{1F1E6}\x{1F1F1}";
  $hash{"flag-am"} = "\x{1F1E6}\x{1F1F2}";
  $hash{"flag-ao"} = "\x{1F1E6}\x{1F1F4}";
  $hash{"flag-aq"} = "\x{1F1E6}\x{1F1F6}";
  $hash{"flag-ar"} = "\x{1F1E6}\x{1F1F7}";
  $hash{"flag-as"} = "\x{1F1E6}\x{1F1F8}";
  $hash{"flag-at"} = "\x{1F1E6}\x{1F1F9}";
  $hash{"flag-au"} = "\x{1F1E6}\x{1F1FA}";
  $hash{"flag-aw"} = "\x{1F1E6}\x{1F1FC}";
  $hash{"flag-ax"} = "\x{1F1E6}\x{1F1FD}";
  $hash{"flag-az"} = "\x{1F1E6}\x{1F1FF}";
  $hash{"flag-ba"} = "\x{1F1E7}\x{1F1E6}";
  $hash{"flag-bb"} = "\x{1F1E7}\x{1F1E7}";
  $hash{"flag-bd"} = "\x{1F1E7}\x{1F1E9}";
  $hash{"flag-be"} = "\x{1F1E7}\x{1F1EA}";
  $hash{"flag-bf"} = "\x{1F1E7}\x{1F1EB}";
  $hash{"flag-bg"} = "\x{1F1E7}\x{1F1EC}";
  $hash{"flag-bh"} = "\x{1F1E7}\x{1F1ED}";
  $hash{"flag-bi"} = "\x{1F1E7}\x{1F1EE}";
  $hash{"flag-bj"} = "\x{1F1E7}\x{1F1EF}";
  $hash{"flag-bl"} = "\x{1F1E7}\x{1F1F1}";
  $hash{"flag-bm"} = "\x{1F1E7}\x{1F1F2}";
  $hash{"flag-bn"} = "\x{1F1E7}\x{1F1F3}";
  $hash{"flag-bo"} = "\x{1F1E7}\x{1F1F4}";
  $hash{"flag-bq"} = "\x{1F1E7}\x{1F1F6}";
  $hash{"flag-br"} = "\x{1F1E7}\x{1F1F7}";
  $hash{"flag-bs"} = "\x{1F1E7}\x{1F1F8}";
  $hash{"flag-bt"} = "\x{1F1E7}\x{1F1F9}";
  $hash{"flag-bv"} = "\x{1F1E7}\x{1F1FB}";
  $hash{"flag-bw"} = "\x{1F1E7}\x{1F1FC}";
  $hash{"flag-by"} = "\x{1F1E7}\x{1F1FE}";
  $hash{"flag-bz"} = "\x{1F1E7}\x{1F1FF}";
  $hash{"flag-ca"} = "\x{1F1E8}\x{1F1E6}";
  $hash{"flag-cc"} = "\x{1F1E8}\x{1F1E8}";
  $hash{"flag-cd"} = "\x{1F1E8}\x{1F1E9}";
  $hash{"flag-cf"} = "\x{1F1E8}\x{1F1EB}";
  $hash{"flag-cg"} = "\x{1F1E8}\x{1F1EC}";
  $hash{"flag-ch"} = "\x{1F1E8}\x{1F1ED}";
  $hash{"flag-ci"} = "\x{1F1E8}\x{1F1EE}";
  $hash{"flag-ck"} = "\x{1F1E8}\x{1F1F0}";
  $hash{"flag-cl"} = "\x{1F1E8}\x{1F1F1}";
  $hash{"flag-cm"} = "\x{1F1E8}\x{1F1F2}";
  $hash{"flag-cn"} = "\x{1F1E8}\x{1F1F3}";
  $hash{"flag-co"} = "\x{1F1E8}\x{1F1F4}";
  $hash{"flag-cp"} = "\x{1F1E8}\x{1F1F5}";
  $hash{"flag-cr"} = "\x{1F1E8}\x{1F1F7}";
  $hash{"flag-cu"} = "\x{1F1E8}\x{1F1FA}";
  $hash{"flag-cv"} = "\x{1F1E8}\x{1F1FB}";
  $hash{"flag-cw"} = "\x{1F1E8}\x{1F1FC}";
  $hash{"flag-cx"} = "\x{1F1E8}\x{1F1FD}";
  $hash{"flag-cy"} = "\x{1F1E8}\x{1F1FE}";
  $hash{"flag-cz"} = "\x{1F1E8}\x{1F1FF}";
  $hash{"flag-de"} = "\x{1F1E9}\x{1F1EA}";
  $hash{"flag-dg"} = "\x{1F1E9}\x{1F1EC}";
  $hash{"flag-dj"} = "\x{1F1E9}\x{1F1EF}";
  $hash{"flag-dk"} = "\x{1F1E9}\x{1F1F0}";
  $hash{"flag-dm"} = "\x{1F1E9}\x{1F1F2}";
  $hash{"flag-do"} = "\x{1F1E9}\x{1F1F4}";
  $hash{"flag-dz"} = "\x{1F1E9}\x{1F1FF}";
  $hash{"flag-ea"} = "\x{1F1EA}\x{1F1E6}";
  $hash{"flag-ec"} = "\x{1F1EA}\x{1F1E8}";
  $hash{"flag-ee"} = "\x{1F1EA}\x{1F1EA}";
  $hash{"flag-eg"} = "\x{1F1EA}\x{1F1EC}";
  $hash{"flag-eh"} = "\x{1F1EA}\x{1F1ED}";
  $hash{"flag-er"} = "\x{1F1EA}\x{1F1F7}";
  $hash{"flag-es"} = "\x{1F1EA}\x{1F1F8}";
  $hash{"flag-et"} = "\x{1F1EA}\x{1F1F9}";
  $hash{"flag-eu"} = "\x{1F1EA}\x{1F1FA}";
  $hash{"flag-fi"} = "\x{1F1EB}\x{1F1EE}";
  $hash{"flag-fj"} = "\x{1F1EB}\x{1F1EF}";
  $hash{"flag-fk"} = "\x{1F1EB}\x{1F1F0}";
  $hash{"flag-fm"} = "\x{1F1EB}\x{1F1F2}";
  $hash{"flag-fo"} = "\x{1F1EB}\x{1F1F4}";
  $hash{"flag-fr"} = "\x{1F1EB}\x{1F1F7}";
  $hash{"flag-ga"} = "\x{1F1EC}\x{1F1E6}";
  $hash{"flag-gb"} = "\x{1F1EC}\x{1F1E7}";
  $hash{"flag-gd"} = "\x{1F1EC}\x{1F1E9}";
  $hash{"flag-ge"} = "\x{1F1EC}\x{1F1EA}";
  $hash{"flag-gf"} = "\x{1F1EC}\x{1F1EB}";
  $hash{"flag-gg"} = "\x{1F1EC}\x{1F1EC}";
  $hash{"flag-gh"} = "\x{1F1EC}\x{1F1ED}";
  $hash{"flag-gi"} = "\x{1F1EC}\x{1F1EE}";
  $hash{"flag-gl"} = "\x{1F1EC}\x{1F1F1}";
  $hash{"flag-gm"} = "\x{1F1EC}\x{1F1F2}";
  $hash{"flag-gn"} = "\x{1F1EC}\x{1F1F3}";
  $hash{"flag-gp"} = "\x{1F1EC}\x{1F1F5}";
  $hash{"flag-gq"} = "\x{1F1EC}\x{1F1F6}";
  $hash{"flag-gr"} = "\x{1F1EC}\x{1F1F7}";
  $hash{"flag-gs"} = "\x{1F1EC}\x{1F1F8}";
  $hash{"flag-gt"} = "\x{1F1EC}\x{1F1F9}";
  $hash{"flag-gu"} = "\x{1F1EC}\x{1F1FA}";
  $hash{"flag-gw"} = "\x{1F1EC}\x{1F1FC}";
  $hash{"flag-gy"} = "\x{1F1EC}\x{1F1FE}";
  $hash{"flag-hk"} = "\x{1F1ED}\x{1F1F0}";
  $hash{"flag-hm"} = "\x{1F1ED}\x{1F1F2}";
  $hash{"flag-hn"} = "\x{1F1ED}\x{1F1F3}";
  $hash{"flag-hr"} = "\x{1F1ED}\x{1F1F7}";
  $hash{"flag-ht"} = "\x{1F1ED}\x{1F1F9}";
  $hash{"flag-hu"} = "\x{1F1ED}\x{1F1FA}";
  $hash{"flag-ic"} = "\x{1F1EE}\x{1F1E8}";
  $hash{"flag-id"} = "\x{1F1EE}\x{1F1E9}";
  $hash{"flag-ie"} = "\x{1F1EE}\x{1F1EA}";
  $hash{"flag-il"} = "\x{1F1EE}\x{1F1F1}";
  $hash{"flag-im"} = "\x{1F1EE}\x{1F1F2}";
  $hash{"flag-in"} = "\x{1F1EE}\x{1F1F3}";
  $hash{"flag-io"} = "\x{1F1EE}\x{1F1F4}";
  $hash{"flag-iq"} = "\x{1F1EE}\x{1F1F6}";
  $hash{"flag-ir"} = "\x{1F1EE}\x{1F1F7}";
  $hash{"flag-is"} = "\x{1F1EE}\x{1F1F8}";
  $hash{"flag-it"} = "\x{1F1EE}\x{1F1F9}";
  $hash{"flag-je"} = "\x{1F1EF}\x{1F1EA}";
  $hash{"flag-jm"} = "\x{1F1EF}\x{1F1F2}";
  $hash{"flag-jo"} = "\x{1F1EF}\x{1F1F4}";
  $hash{"flag-jp"} = "\x{1F1EF}\x{1F1F5}";
  $hash{"flag-ke"} = "\x{1F1F0}\x{1F1EA}";
  $hash{"flag-kg"} = "\x{1F1F0}\x{1F1EC}";
  $hash{"flag-kh"} = "\x{1F1F0}\x{1F1ED}";
  $hash{"flag-ki"} = "\x{1F1F0}\x{1F1EE}";
  $hash{"flag-km"} = "\x{1F1F0}\x{1F1F2}";
  $hash{"flag-kn"} = "\x{1F1F0}\x{1F1F3}";
  $hash{"flag-kp"} = "\x{1F1F0}\x{1F1F5}";
  $hash{"flag-kr"} = "\x{1F1F0}\x{1F1F7}";
  $hash{"flag-kw"} = "\x{1F1F0}\x{1F1FC}";
  $hash{"flag-ky"} = "\x{1F1F0}\x{1F1FE}";
  $hash{"flag-kz"} = "\x{1F1F0}\x{1F1FF}";
  $hash{"flag-la"} = "\x{1F1F1}\x{1F1E6}";
  $hash{"flag-lb"} = "\x{1F1F1}\x{1F1E7}";
  $hash{"flag-lc"} = "\x{1F1F1}\x{1F1E8}";
  $hash{"flag-li"} = "\x{1F1F1}\x{1F1EE}";
  $hash{"flag-lk"} = "\x{1F1F1}\x{1F1F0}";
  $hash{"flag-lr"} = "\x{1F1F1}\x{1F1F7}";
  $hash{"flag-ls"} = "\x{1F1F1}\x{1F1F8}";
  $hash{"flag-lt"} = "\x{1F1F1}\x{1F1F9}";
  $hash{"flag-lu"} = "\x{1F1F1}\x{1F1FA}";
  $hash{"flag-lv"} = "\x{1F1F1}\x{1F1FB}";
  $hash{"flag-ly"} = "\x{1F1F1}\x{1F1FE}";
  $hash{"flag-ma"} = "\x{1F1F2}\x{1F1E6}";
  $hash{"flag-mc"} = "\x{1F1F2}\x{1F1E8}";
  $hash{"flag-md"} = "\x{1F1F2}\x{1F1E9}";
  $hash{"flag-me"} = "\x{1F1F2}\x{1F1EA}";
  $hash{"flag-mf"} = "\x{1F1F2}\x{1F1EB}";
  $hash{"flag-mg"} = "\x{1F1F2}\x{1F1EC}";
  $hash{"flag-mh"} = "\x{1F1F2}\x{1F1ED}";
  $hash{"flag-mk"} = "\x{1F1F2}\x{1F1F0}";
  $hash{"flag-ml"} = "\x{1F1F2}\x{1F1F1}";
  $hash{"flag-mm"} = "\x{1F1F2}\x{1F1F2}";
  $hash{"flag-mn"} = "\x{1F1F2}\x{1F1F3}";
  $hash{"flag-mo"} = "\x{1F1F2}\x{1F1F4}";
  $hash{"flag-mp"} = "\x{1F1F2}\x{1F1F5}";
  $hash{"flag-mq"} = "\x{1F1F2}\x{1F1F6}";
  $hash{"flag-mr"} = "\x{1F1F2}\x{1F1F7}";
  $hash{"flag-ms"} = "\x{1F1F2}\x{1F1F8}";
  $hash{"flag-mt"} = "\x{1F1F2}\x{1F1F9}";
  $hash{"flag-mu"} = "\x{1F1F2}\x{1F1FA}";
  $hash{"flag-mv"} = "\x{1F1F2}\x{1F1FB}";
  $hash{"flag-mw"} = "\x{1F1F2}\x{1F1FC}";
  $hash{"flag-mx"} = "\x{1F1F2}\x{1F1FD}";
  $hash{"flag-my"} = "\x{1F1F2}\x{1F1FE}";
  $hash{"flag-mz"} = "\x{1F1F2}\x{1F1FF}";
  $hash{"flag-na"} = "\x{1F1F3}\x{1F1E6}";
  $hash{"flag-nc"} = "\x{1F1F3}\x{1F1E8}";
  $hash{"flag-ne"} = "\x{1F1F3}\x{1F1EA}";
  $hash{"flag-nf"} = "\x{1F1F3}\x{1F1EB}";
  $hash{"flag-ng"} = "\x{1F1F3}\x{1F1EC}";
  $hash{"flag-ni"} = "\x{1F1F3}\x{1F1EE}";
  $hash{"flag-nl"} = "\x{1F1F3}\x{1F1F1}";
  $hash{"flag-no"} = "\x{1F1F3}\x{1F1F4}";
  $hash{"flag-np"} = "\x{1F1F3}\x{1F1F5}";
  $hash{"flag-nr"} = "\x{1F1F3}\x{1F1F7}";
  $hash{"flag-nu"} = "\x{1F1F3}\x{1F1FA}";
  $hash{"flag-nz"} = "\x{1F1F3}\x{1F1FF}";
  $hash{"flag-om"} = "\x{1F1F4}\x{1F1F2}";
  $hash{"flag-pa"} = "\x{1F1F5}\x{1F1E6}";
  $hash{"flag-pe"} = "\x{1F1F5}\x{1F1EA}";
  $hash{"flag-pf"} = "\x{1F1F5}\x{1F1EB}";
  $hash{"flag-pg"} = "\x{1F1F5}\x{1F1EC}";
  $hash{"flag-ph"} = "\x{1F1F5}\x{1F1ED}";
  $hash{"flag-pk"} = "\x{1F1F5}\x{1F1F0}";
  $hash{"flag-pl"} = "\x{1F1F5}\x{1F1F1}";
  $hash{"flag-pm"} = "\x{1F1F5}\x{1F1F2}";
  $hash{"flag-pn"} = "\x{1F1F5}\x{1F1F3}";
  $hash{"flag-pr"} = "\x{1F1F5}\x{1F1F7}";
  $hash{"flag-ps"} = "\x{1F1F5}\x{1F1F8}";
  $hash{"flag-pt"} = "\x{1F1F5}\x{1F1F9}";
  $hash{"flag-pw"} = "\x{1F1F5}\x{1F1FC}";
  $hash{"flag-py"} = "\x{1F1F5}\x{1F1FE}";
  $hash{"flag-qa"} = "\x{1F1F6}\x{1F1E6}";
  $hash{"flag-re"} = "\x{1F1F7}\x{1F1EA}";
  $hash{"flag-ro"} = "\x{1F1F7}\x{1F1F4}";
  $hash{"flag-rs"} = "\x{1F1F7}\x{1F1F8}";
  $hash{"flag-ru"} = "\x{1F1F7}\x{1F1FA}";
  $hash{"flag-rw"} = "\x{1F1F7}\x{1F1FC}";
  $hash{"flag-sa"} = "\x{1F1F8}\x{1F1E6}";
  $hash{"flag-sb"} = "\x{1F1F8}\x{1F1E7}";
  $hash{"flag-sc"} = "\x{1F1F8}\x{1F1E8}";
  $hash{"flag-sd"} = "\x{1F1F8}\x{1F1E9}";
  $hash{"flag-se"} = "\x{1F1F8}\x{1F1EA}";
  $hash{"flag-sg"} = "\x{1F1F8}\x{1F1EC}";
  $hash{"flag-sh"} = "\x{1F1F8}\x{1F1ED}";
  $hash{"flag-si"} = "\x{1F1F8}\x{1F1EE}";
  $hash{"flag-sj"} = "\x{1F1F8}\x{1F1EF}";
  $hash{"flag-sk"} = "\x{1F1F8}\x{1F1F0}";
  $hash{"flag-sl"} = "\x{1F1F8}\x{1F1F1}";
  $hash{"flag-sm"} = "\x{1F1F8}\x{1F1F2}";
  $hash{"flag-sn"} = "\x{1F1F8}\x{1F1F3}";
  $hash{"flag-so"} = "\x{1F1F8}\x{1F1F4}";
  $hash{"flag-sr"} = "\x{1F1F8}\x{1F1F7}";
  $hash{"flag-ss"} = "\x{1F1F8}\x{1F1F8}";
  $hash{"flag-st"} = "\x{1F1F8}\x{1F1F9}";
  $hash{"flag-sv"} = "\x{1F1F8}\x{1F1FB}";
  $hash{"flag-sx"} = "\x{1F1F8}\x{1F1FD}";
  $hash{"flag-sy"} = "\x{1F1F8}\x{1F1FE}";
  $hash{"flag-sz"} = "\x{1F1F8}\x{1F1FF}";
  $hash{"flag-ta"} = "\x{1F1F9}\x{1F1E6}";
  $hash{"flag-tc"} = "\x{1F1F9}\x{1F1E8}";
  $hash{"flag-td"} = "\x{1F1F9}\x{1F1E9}";
  $hash{"flag-tf"} = "\x{1F1F9}\x{1F1EB}";
  $hash{"flag-tg"} = "\x{1F1F9}\x{1F1EC}";
  $hash{"flag-th"} = "\x{1F1F9}\x{1F1ED}";
  $hash{"flag-tj"} = "\x{1F1F9}\x{1F1EF}";
  $hash{"flag-tk"} = "\x{1F1F9}\x{1F1F0}";
  $hash{"flag-tl"} = "\x{1F1F9}\x{1F1F1}";
  $hash{"flag-tm"} = "\x{1F1F9}\x{1F1F2}";
  $hash{"flag-tn"} = "\x{1F1F9}\x{1F1F3}";
  $hash{"flag-to"} = "\x{1F1F9}\x{1F1F4}";
  $hash{"flag-tr"} = "\x{1F1F9}\x{1F1F7}";
  $hash{"flag-tt"} = "\x{1F1F9}\x{1F1F9}";
  $hash{"flag-tv"} = "\x{1F1F9}\x{1F1FB}";
  $hash{"flag-tw"} = "\x{1F1F9}\x{1F1FC}";
  $hash{"flag-tz"} = "\x{1F1F9}\x{1F1FF}";
  $hash{"flag-ua"} = "\x{1F1FA}\x{1F1E6}";
  $hash{"flag-ug"} = "\x{1F1FA}\x{1F1EC}";
  $hash{"flag-um"} = "\x{1F1FA}\x{1F1F2}";
  $hash{"flag-un"} = "\x{1F1FA}\x{1F1F3}";
  $hash{"flag-us"} = "\x{1F1FA}\x{1F1F8}";
  $hash{"flag-uy"} = "\x{1F1FA}\x{1F1FE}";
  $hash{"flag-uz"} = "\x{1F1FA}\x{1F1FF}";
  $hash{"flag-va"} = "\x{1F1FB}\x{1F1E6}";
  $hash{"flag-vc"} = "\x{1F1FB}\x{1F1E8}";
  $hash{"flag-ve"} = "\x{1F1FB}\x{1F1EA}";
  $hash{"flag-vg"} = "\x{1F1FB}\x{1F1EC}";
  $hash{"flag-vi"} = "\x{1F1FB}\x{1F1EE}";
  $hash{"flag-vn"} = "\x{1F1FB}\x{1F1F3}";
  $hash{"flag-vu"} = "\x{1F1FB}\x{1F1FA}";
  $hash{"flag-wf"} = "\x{1F1FC}\x{1F1EB}";
  $hash{"flag-ws"} = "\x{1F1FC}\x{1F1F8}";
  $hash{"flag-xk"} = "\x{1F1FD}\x{1F1F0}";
  $hash{"flag-ye"} = "\x{1F1FE}\x{1F1EA}";
  $hash{"flag-yt"} = "\x{1F1FE}\x{1F1F9}";
  $hash{"flag-za"} = "\x{1F1FF}\x{1F1E6}";
  $hash{"flag-zm"} = "\x{1F1FF}\x{1F1F2}";
  $hash{"flag-zw"} = "\x{1F1FF}\x{1F1FC}";
  $hash{"flags"} = "\x{1F38F}";
  $hash{"flashlight"} = "\x{1F526}";
  $hash{"flipper"} = "\x{1F42C}";
  $hash{"floppy_disk"} = "\x{1F4BE}";
  $hash{"flower_playing_cards"} = "\x{1F3B4}";
  $hash{"flushed"} = "\x{1F633}";
  $hash{"foggy"} = "\x{1F301}";
  $hash{"football"} = "\x{1F3C8}";
  $hash{"footprints"} = "\x{1F463}";
  $hash{"fork_and_knife"} = "\x{1F374}";
  $hash{"four_leaf_clover"} = "\x{1F340}";
  $hash{"fr"} = "\x{1F1EB}\x{1F1F7}";
  $hash{"free"} = "\x{1F193}";
  $hash{"fried_egg"} = "\x{1F373}";
  $hash{"fried_shrimp"} = "\x{1F364}";
  $hash{"fries"} = "\x{1F35F}";
  $hash{"frog"} = "\x{1F438}";
  $hash{"full_moon"} = "\x{1F315}";
  $hash{"full_moon_with_face"} = "\x{1F31D}";
  $hash{"game_die"} = "\x{1F3B2}";
  $hash{"gb"} = "\x{1F1EC}\x{1F1E7}";
  $hash{"gem"} = "\x{1F48E}";
  $hash{"ghost"} = "\x{1F47B}";
  $hash{"gift"} = "\x{1F381}";
  $hash{"gift_heart"} = "\x{1F49D}";
  $hash{"girl"} = "\x{1F467}";
  $hash{"globe_with_meridians"} = "\x{1F310}";
  $hash{"goat"} = "\x{1F410}";
  $hash{"grapes"} = "\x{1F347}";
  $hash{"green_apple"} = "\x{1F34F}";
  $hash{"green_book"} = "\x{1F4D7}";
  $hash{"green_heart"} = "\x{1F49A}";
  $hash{"grey_exclamation"} = "\x{2755}";
  $hash{"grey_question"} = "\x{2754}";
  $hash{"grin"} = "\x{1F601}";
  $hash{"guardsman"} = "\x{1F482}";
  $hash{"guitar"} = "\x{1F3B8}";
  $hash{"gun"} = "\x{1F52B}";
  $hash{"haircut"} = "\x{1F487}";
  $hash{"hamburger"} = "\x{1F354}";
  $hash{"hammer"} = "\x{1F528}";
  $hash{"hamster"} = "\x{1F439}";
  $hash{"hand"} = "\x{270B}";
  $hash{"handbag"} = "\x{1F45C}";
  $hash{"hankey"} = "\x{1F4A9}";
  $hash{"hatched_chick"} = "\x{1F425}";
  $hash{"hatching_chick"} = "\x{1F423}";
  $hash{"headphones"} = "\x{1F3A7}";
  $hash{"hear_no_evil"} = "\x{1F649}";
  $hash{"heart_decoration"} = "\x{1F49F}";
  $hash{"heart_eyes"} = "\x{1F60D}";
  $hash{"heart_eyes_cat"} = "\x{1F63B}";
  $hash{"heartbeat"} = "\x{1F493}";
  $hash{"heartpulse"} = "\x{1F497}";
  $hash{"heavy_division_sign"} = "\x{2797}";
  $hash{"heavy_dollar_sign"} = "\x{1F4B2}";
  $hash{"heavy_minus_sign"} = "\x{2796}";
  $hash{"heavy_plus_sign"} = "\x{2795}";
  $hash{"helicopter"} = "\x{1F681}";
  $hash{"herb"} = "\x{1F33F}";
  $hash{"hibiscus"} = "\x{1F33A}";
  $hash{"high_brightness"} = "\x{1F506}";
  $hash{"high_heel"} = "\x{1F460}";
  $hash{"hocho"} = "\x{1F52A}";
  $hash{"honey_pot"} = "\x{1F36F}";
  $hash{"honeybee"} = "\x{1F41D}";
  $hash{"horse"} = "\x{1F434}";
  $hash{"horse_racing"} = "\x{1F3C7}";
  $hash{"hospital"} = "\x{1F3E5}";
  $hash{"hotel"} = "\x{1F3E8}";
  $hash{"hourglass_flowing_sand"} = "\x{23F3}";
  $hash{"house"} = "\x{1F3E0}";
  $hash{"house_with_garden"} = "\x{1F3E1}";
  $hash{"ice_cream"} = "\x{1F368}";
  $hash{"icecream"} = "\x{1F366}";
  $hash{"id"} = "\x{1F194}";
  $hash{"ideograph_advantage"} = "\x{1F250}";
  $hash{"imp"} = "\x{1F47F}";
  $hash{"inbox_tray"} = "\x{1F4E5}";
  $hash{"incoming_envelope"} = "\x{1F4E8}";
  $hash{"information_desk_person"} = "\x{1F481}";
  $hash{"innocent"} = "\x{1F607}";
  $hash{"iphone"} = "\x{1F4F1}";
  $hash{"it"} = "\x{1F1EE}\x{1F1F9}";
  $hash{"izakaya_lantern"} = "\x{1F3EE}";
  $hash{"jack_o_lantern"} = "\x{1F383}";
  $hash{"japan"} = "\x{1F5FE}";
  $hash{"japanese_castle"} = "\x{1F3EF}";
  $hash{"japanese_goblin"} = "\x{1F47A}";
  $hash{"japanese_ogre"} = "\x{1F479}";
  $hash{"jeans"} = "\x{1F456}";
  $hash{"joy"} = "\x{1F602}";
  $hash{"joy_cat"} = "\x{1F639}";
  $hash{"jp"} = "\x{1F1EF}\x{1F1F5}";
  $hash{"key"} = "\x{1F511}";
  $hash{"keycap_ten"} = "\x{1F51F}";
  $hash{"kimono"} = "\x{1F458}";
  $hash{"kiss"} = "\x{1F48B}";
  $hash{"kissing_cat"} = "\x{1F63D}";
  $hash{"kissing_closed_eyes"} = "\x{1F61A}";
  $hash{"kissing_heart"} = "\x{1F618}";
  $hash{"knife"} = "\x{1F52A}";
  $hash{"koala"} = "\x{1F428}";
  $hash{"koko"} = "\x{1F201}";
  $hash{"kr"} = "\x{1F1F0}\x{1F1F7}";
  $hash{"lady_beetle"} = "\x{1F41E}";
  $hash{"ladybug"} = "\x{1F41E}";
  $hash{"lantern"} = "\x{1F3EE}";
  $hash{"large_blue_circle"} = "\x{1F535}";
  $hash{"large_blue_diamond"} = "\x{1F537}";
  $hash{"large_orange_diamond"} = "\x{1F536}";
  $hash{"last_quarter_moon"} = "\x{1F317}";
  $hash{"last_quarter_moon_with_face"} = "\x{1F31C}";
  $hash{"laughing"} = "\x{1F606}";
  $hash{"leaves"} = "\x{1F343}";
  $hash{"ledger"} = "\x{1F4D2}";
  $hash{"left_luggage"} = "\x{1F6C5}";
  $hash{"lemon"} = "\x{1F34B}";
  $hash{"leopard"} = "\x{1F406}";
  $hash{"light_rail"} = "\x{1F688}";
  $hash{"link"} = "\x{1F517}";
  $hash{"lips"} = "\x{1F444}";
  $hash{"lipstick"} = "\x{1F484}";
  $hash{"lock"} = "\x{1F512}";
  $hash{"lock_with_ink_pen"} = "\x{1F50F}";
  $hash{"lollipop"} = "\x{1F36D}";
  $hash{"loop"} = "\x{27BF}";
  $hash{"loud_sound"} = "\x{1F50A}";
  $hash{"loudspeaker"} = "\x{1F4E2}";
  $hash{"love_hotel"} = "\x{1F3E9}";
  $hash{"love_letter"} = "\x{1F48C}";
  $hash{"low_brightness"} = "\x{1F505}";
  $hash{"mag"} = "\x{1F50D}";
  $hash{"mag_right"} = "\x{1F50E}";
  $hash{"mailbox"} = "\x{1F4EB}";
  $hash{"mailbox_closed"} = "\x{1F4EA}";
  $hash{"mailbox_with_mail"} = "\x{1F4EC}";
  $hash{"mailbox_with_no_mail"} = "\x{1F4ED}";
  $hash{"male-artist"} = "\x{1F468}\x{200D}\x{1F3A8}";
  $hash{"male-astronaut"} = "\x{1F468}\x{200D}\x{1F680}";
  $hash{"male-construction-worker"} = "\x{1F477}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male-cook"} = "\x{1F468}\x{200D}\x{1F373}";
  $hash{"male-doctor"} = "\x{1F468}\x{200D}\x{2695}\x{FE0F}";
  $hash{"male-factory-worker"} = "\x{1F468}\x{200D}\x{1F3ED}";
  $hash{"male-farmer"} = "\x{1F468}\x{200D}\x{1F33E}";
  $hash{"male-firefighter"} = "\x{1F468}\x{200D}\x{1F692}";
  $hash{"male-guard"} = "\x{1F482}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male-judge"} = "\x{1F468}\x{200D}\x{2696}\x{FE0F}";
  $hash{"male-mechanic"} = "\x{1F468}\x{200D}\x{1F527}";
  $hash{"male-office-worker"} = "\x{1F468}\x{200D}\x{1F4BC}";
  $hash{"male-pilot"} = "\x{1F468}\x{200D}\x{2708}\x{FE0F}";
  $hash{"male-police-officer"} = "\x{1F46E}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male-scientist"} = "\x{1F468}\x{200D}\x{1F52C}";
  $hash{"male-singer"} = "\x{1F468}\x{200D}\x{1F3A4}";
  $hash{"male-student"} = "\x{1F468}\x{200D}\x{1F393}";
  $hash{"male-teacher"} = "\x{1F468}\x{200D}\x{1F3EB}";
  $hash{"male-technologist"} = "\x{1F468}\x{200D}\x{1F4BB}";
  $hash{"man"} = "\x{1F468}";
  $hash{"man-biking"} = "\x{1F6B4}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-bowing"} = "\x{1F647}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-boy"} = "\x{1F468}\x{200D}\x{1F466}";
  $hash{"man-boy-boy"} = "\x{1F468}\x{200D}\x{1F466}\x{200D}\x{1F466}";
  $hash{"man-frowning"} = "\x{1F64D}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-gesturing-no"} = "\x{1F645}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-gesturing-ok"} = "\x{1F646}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-getting-haircut"} = "\x{1F487}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-getting-massage"} = "\x{1F486}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-girl"} = "\x{1F468}\x{200D}\x{1F467}";
  $hash{"man-girl-boy"} = "\x{1F468}\x{200D}\x{1F467}\x{200D}\x{1F466}";
  $hash{"man-girl-girl"} = "\x{1F468}\x{200D}\x{1F467}\x{200D}\x{1F467}";
  $hash{"man-heart-man"} = "\x{1F468}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F468}";
  $hash{"man-kiss-man"} = "\x{1F468}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F48B}\x{200D}\x{1F468}";
  $hash{"man-man-boy"} = "\x{1F468}\x{200D}\x{1F468}\x{200D}\x{1F466}";
  $hash{"man-man-boy-boy"} = "\x{1F468}\x{200D}\x{1F468}\x{200D}\x{1F466}\x{200D}\x{1F466}";
  $hash{"man-man-girl"} = "\x{1F468}\x{200D}\x{1F468}\x{200D}\x{1F467}";
  $hash{"man-man-girl-boy"} = "\x{1F468}\x{200D}\x{1F468}\x{200D}\x{1F467}\x{200D}\x{1F466}";
  $hash{"man-man-girl-girl"} = "\x{1F468}\x{200D}\x{1F468}\x{200D}\x{1F467}\x{200D}\x{1F467}";
  $hash{"man-mountain-biking"} = "\x{1F6B5}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-pouting"} = "\x{1F64E}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-raising-hand"} = "\x{1F64B}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-rowing-boat"} = "\x{1F6A3}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-running"} = "\x{1F3C3}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-surfing"} = "\x{1F3C4}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-swimming"} = "\x{1F3CA}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-tipping-hand"} = "\x{1F481}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-walking"} = "\x{1F6B6}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-wearing-turban"} = "\x{1F473}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-woman-boy"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F466}";
  $hash{"man-woman-boy-boy"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F466}\x{200D}\x{1F466}";
  $hash{"man-woman-girl"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F467}";
  $hash{"man-woman-girl-boy"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F466}";
  $hash{"man-woman-girl-girl"} = "\x{1F468}\x{200D}\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F467}";
  $hash{"man_and_woman_holding_hands"} = "\x{1F46B}";
  $hash{"man_with_gua_pi_mao"} = "\x{1F472}";
  $hash{"man_with_turban"} = "\x{1F473}";
  $hash{"mans_shoe"} = "\x{1F45E}";
  $hash{"maple_leaf"} = "\x{1F341}";
  $hash{"mask"} = "\x{1F637}";
  $hash{"massage"} = "\x{1F486}";
  $hash{"meat_on_bone"} = "\x{1F356}";
  $hash{"mega"} = "\x{1F4E3}";
  $hash{"melon"} = "\x{1F348}";
  $hash{"memo"} = "\x{1F4DD}";
  $hash{"men-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"men_holding_hands"} = "\x{1F46C}";
  $hash{"mens"} = "\x{1F6B9}";
  $hash{"metro"} = "\x{1F687}";
  $hash{"microphone"} = "\x{1F3A4}";
  $hash{"microscope"} = "\x{1F52C}";
  $hash{"milky_way"} = "\x{1F30C}";
  $hash{"minibus"} = "\x{1F690}";
  $hash{"minidisc"} = "\x{1F4BD}";
  $hash{"mobile_phone_off"} = "\x{1F4F4}";
  $hash{"money_with_wings"} = "\x{1F4B8}";
  $hash{"moneybag"} = "\x{1F4B0}";
  $hash{"monkey"} = "\x{1F412}";
  $hash{"monkey_face"} = "\x{1F435}";
  $hash{"monorail"} = "\x{1F69D}";
  $hash{"moon"} = "\x{1F314}";
  $hash{"mortar_board"} = "\x{1F393}";
  $hash{"mount_fuji"} = "\x{1F5FB}";
  $hash{"mountain_bicyclist"} = "\x{1F6B5}";
  $hash{"mountain_cableway"} = "\x{1F6A0}";
  $hash{"mountain_railway"} = "\x{1F69E}";
  $hash{"mouse"} = "\x{1F42D}";
  $hash{"mouse2"} = "\x{1F401}";
  $hash{"movie_camera"} = "\x{1F3A5}";
  $hash{"moyai"} = "\x{1F5FF}";
  $hash{"muscle"} = "\x{1F4AA}";
  $hash{"mushroom"} = "\x{1F344}";
  $hash{"musical_keyboard"} = "\x{1F3B9}";
  $hash{"musical_note"} = "\x{1F3B5}";
  $hash{"musical_score"} = "\x{1F3BC}";
  $hash{"mute"} = "\x{1F507}";
  $hash{"nail_care"} = "\x{1F485}";
  $hash{"name_badge"} = "\x{1F4DB}";
  $hash{"necktie"} = "\x{1F454}";
  $hash{"negative_squared_cross_mark"} = "\x{274E}";
  $hash{"neutral_face"} = "\x{1F610}";
  $hash{"new"} = "\x{1F195}";
  $hash{"new_moon"} = "\x{1F311}";
  $hash{"new_moon_with_face"} = "\x{1F31A}";
  $hash{"newspaper"} = "\x{1F4F0}";
  $hash{"ng"} = "\x{1F196}";
  $hash{"night_with_stars"} = "\x{1F303}";
  $hash{"no_bell"} = "\x{1F515}";
  $hash{"no_bicycles"} = "\x{1F6B3}";
  $hash{"no_entry_sign"} = "\x{1F6AB}";
  $hash{"no_good"} = "\x{1F645}";
  $hash{"no_mobile_phones"} = "\x{1F4F5}";
  $hash{"no_mouth"} = "\x{1F636}";
  $hash{"no_pedestrians"} = "\x{1F6B7}";
  $hash{"no_smoking"} = "\x{1F6AD}";
  $hash{"non-potable_water"} = "\x{1F6B1}";
  $hash{"nose"} = "\x{1F443}";
  $hash{"notebook"} = "\x{1F4D3}";
  $hash{"notebook_with_decorative_cover"} = "\x{1F4D4}";
  $hash{"notes"} = "\x{1F3B6}";
  $hash{"nut_and_bolt"} = "\x{1F529}";
  $hash{"o2"} = "\x{1F17E}\x{FE0F}";
  $hash{"ocean"} = "\x{1F30A}";
  $hash{"octopus"} = "\x{1F419}";
  $hash{"oden"} = "\x{1F362}";
  $hash{"office"} = "\x{1F3E2}";
  $hash{"ok"} = "\x{1F197}";
  $hash{"ok_hand"} = "\x{1F44C}";
  $hash{"ok_woman"} = "\x{1F646}";
  $hash{"older_man"} = "\x{1F474}";
  $hash{"older_woman"} = "\x{1F475}";
  $hash{"on"} = "\x{1F51B}";
  $hash{"oncoming_automobile"} = "\x{1F698}";
  $hash{"oncoming_bus"} = "\x{1F68D}";
  $hash{"oncoming_police_car"} = "\x{1F694}";
  $hash{"oncoming_taxi"} = "\x{1F696}";
  $hash{"open_book"} = "\x{1F4D6}";
  $hash{"open_file_folder"} = "\x{1F4C2}";
  $hash{"open_hands"} = "\x{1F450}";
  $hash{"ophiuchus"} = "\x{26CE}";
  $hash{"orange_book"} = "\x{1F4D9}";
  $hash{"outbox_tray"} = "\x{1F4E4}";
  $hash{"ox"} = "\x{1F402}";
  $hash{"package"} = "\x{1F4E6}";
  $hash{"page_facing_up"} = "\x{1F4C4}";
  $hash{"page_with_curl"} = "\x{1F4C3}";
  $hash{"pager"} = "\x{1F4DF}";
  $hash{"palm_tree"} = "\x{1F334}";
  $hash{"panda_face"} = "\x{1F43C}";
  $hash{"paperclip"} = "\x{1F4CE}";
  $hash{"passport_control"} = "\x{1F6C2}";
  $hash{"paw_prints"} = "\x{1F43E}";
  $hash{"peach"} = "\x{1F351}";
  $hash{"pear"} = "\x{1F350}";
  $hash{"pencil"} = "\x{1F4DD}";
  $hash{"penguin"} = "\x{1F427}";
  $hash{"pensive"} = "\x{1F614}";
  $hash{"performing_arts"} = "\x{1F3AD}";
  $hash{"persevere"} = "\x{1F623}";
  $hash{"person_frowning"} = "\x{1F64D}";
  $hash{"person_with_blond_hair"} = "\x{1F471}";
  $hash{"person_with_pouting_face"} = "\x{1F64E}";
  $hash{"pig"} = "\x{1F437}";
  $hash{"pig2"} = "\x{1F416}";
  $hash{"pig_nose"} = "\x{1F43D}";
  $hash{"pill"} = "\x{1F48A}";
  $hash{"pineapple"} = "\x{1F34D}";
  $hash{"pizza"} = "\x{1F355}";
  $hash{"point_down"} = "\x{1F447}";
  $hash{"point_left"} = "\x{1F448}";
  $hash{"point_right"} = "\x{1F449}";
  $hash{"point_up_2"} = "\x{1F446}";
  $hash{"police_car"} = "\x{1F693}";
  $hash{"poodle"} = "\x{1F429}";
  $hash{"poop"} = "\x{1F4A9}";
  $hash{"post_office"} = "\x{1F3E3}";
  $hash{"postal_horn"} = "\x{1F4EF}";
  $hash{"postbox"} = "\x{1F4EE}";
  $hash{"potable_water"} = "\x{1F6B0}";
  $hash{"pouch"} = "\x{1F45D}";
  $hash{"poultry_leg"} = "\x{1F357}";
  $hash{"pound"} = "\x{1F4B7}";
  $hash{"pouting_cat"} = "\x{1F63E}";
  $hash{"pray"} = "\x{1F64F}";
  $hash{"princess"} = "\x{1F478}";
  $hash{"punch"} = "\x{1F44A}";
  $hash{"purple_heart"} = "\x{1F49C}";
  $hash{"purse"} = "\x{1F45B}";
  $hash{"pushpin"} = "\x{1F4CC}";
  $hash{"put_litter_in_its_place"} = "\x{1F6AE}";
  $hash{"question"} = "\x{2753}";
  $hash{"rabbit"} = "\x{1F430}";
  $hash{"rabbit2"} = "\x{1F407}";
  $hash{"racehorse"} = "\x{1F40E}";
  $hash{"radio"} = "\x{1F4FB}";
  $hash{"radio_button"} = "\x{1F518}";
  $hash{"rage"} = "\x{1F621}";
  $hash{"railway_car"} = "\x{1F683}";
  $hash{"rainbow"} = "\x{1F308}";
  $hash{"raised_hand"} = "\x{270B}";
  $hash{"raised_hands"} = "\x{1F64C}";
  $hash{"raising_hand"} = "\x{1F64B}";
  $hash{"ram"} = "\x{1F40F}";
  $hash{"ramen"} = "\x{1F35C}";
  $hash{"rat"} = "\x{1F400}";
  $hash{"red_car"} = "\x{1F697}";
  $hash{"red_circle"} = "\x{1F534}";
  $hash{"relieved"} = "\x{1F60C}";
  $hash{"repeat"} = "\x{1F501}";
  $hash{"repeat_one"} = "\x{1F502}";
  $hash{"restroom"} = "\x{1F6BB}";
  $hash{"revolving_hearts"} = "\x{1F49E}";
  $hash{"rewind"} = "\x{23EA}";
  $hash{"ribbon"} = "\x{1F380}";
  $hash{"rice"} = "\x{1F35A}";
  $hash{"rice_ball"} = "\x{1F359}";
  $hash{"rice_cracker"} = "\x{1F358}";
  $hash{"rice_scene"} = "\x{1F391}";
  $hash{"ring"} = "\x{1F48D}";
  $hash{"rocket"} = "\x{1F680}";
  $hash{"roller_coaster"} = "\x{1F3A2}";
  $hash{"rooster"} = "\x{1F413}";
  $hash{"rose"} = "\x{1F339}";
  $hash{"rotating_light"} = "\x{1F6A8}";
  $hash{"round_pushpin"} = "\x{1F4CD}";
  $hash{"rowboat"} = "\x{1F6A3}";
  $hash{"ru"} = "\x{1F1F7}\x{1F1FA}";
  $hash{"rugby_football"} = "\x{1F3C9}";
  $hash{"runner"} = "\x{1F3C3}";
  $hash{"running"} = "\x{1F3C3}";
  $hash{"running_shirt_with_sash"} = "\x{1F3BD}";
  $hash{"sa"} = "\x{1F202}\x{FE0F}";
  $hash{"sake"} = "\x{1F376}";
  $hash{"sandal"} = "\x{1F461}";
  $hash{"santa"} = "\x{1F385}";
  $hash{"satellite_antenna"} = "\x{1F4E1}";
  $hash{"satisfied"} = "\x{1F606}";
  $hash{"saxophone"} = "\x{1F3B7}";
  $hash{"school"} = "\x{1F3EB}";
  $hash{"school_satchel"} = "\x{1F392}";
  $hash{"scream"} = "\x{1F631}";
  $hash{"scream_cat"} = "\x{1F640}";
  $hash{"scroll"} = "\x{1F4DC}";
  $hash{"seat"} = "\x{1F4BA}";
  $hash{"see_no_evil"} = "\x{1F648}";
  $hash{"seedling"} = "\x{1F331}";
  $hash{"shaved_ice"} = "\x{1F367}";
  $hash{"sheep"} = "\x{1F411}";
  $hash{"shell"} = "\x{1F41A}";
  $hash{"ship"} = "\x{1F6A2}";
  $hash{"shirt"} = "\x{1F455}";
  $hash{"shit"} = "\x{1F4A9}";
  $hash{"shoe"} = "\x{1F45E}";
  $hash{"shower"} = "\x{1F6BF}";
  $hash{"signal_strength"} = "\x{1F4F6}";
  $hash{"six_pointed_star"} = "\x{1F52F}";
  $hash{"ski"} = "\x{1F3BF}";
  $hash{"skull"} = "\x{1F480}";
  $hash{"sleepy"} = "\x{1F62A}";
  $hash{"slot_machine"} = "\x{1F3B0}";
  $hash{"small_blue_diamond"} = "\x{1F539}";
  $hash{"small_orange_diamond"} = "\x{1F538}";
  $hash{"small_red_triangle"} = "\x{1F53A}";
  $hash{"small_red_triangle_down"} = "\x{1F53B}";
  $hash{"smile"} = "\x{1F604}";
  $hash{"smile_cat"} = "\x{1F638}";
  $hash{"smiley"} = "\x{1F603}";
  $hash{"smiley_cat"} = "\x{1F63A}";
  $hash{"smiling_imp"} = "\x{1F608}";
  $hash{"smirk"} = "\x{1F60F}";
  $hash{"smirk_cat"} = "\x{1F63C}";
  $hash{"smoking"} = "\x{1F6AC}";
  $hash{"snail"} = "\x{1F40C}";
  $hash{"snake"} = "\x{1F40D}";
  $hash{"snowboarder"} = "\x{1F3C2}";
  $hash{"sob"} = "\x{1F62D}";
  $hash{"soon"} = "\x{1F51C}";
  $hash{"sos"} = "\x{1F198}";
  $hash{"sound"} = "\x{1F509}";
  $hash{"space_invader"} = "\x{1F47E}";
  $hash{"spaghetti"} = "\x{1F35D}";
  $hash{"sparkler"} = "\x{1F387}";
  $hash{"sparkles"} = "\x{2728}";
  $hash{"sparkling_heart"} = "\x{1F496}";
  $hash{"speak_no_evil"} = "\x{1F64A}";
  $hash{"speaker"} = "\x{1F508}";
  $hash{"speech_balloon"} = "\x{1F4AC}";
  $hash{"speedboat"} = "\x{1F6A4}";
  $hash{"star2"} = "\x{1F31F}";
  $hash{"stars"} = "\x{1F320}";
  $hash{"station"} = "\x{1F689}";
  $hash{"statue_of_liberty"} = "\x{1F5FD}";
  $hash{"steam_locomotive"} = "\x{1F682}";
  $hash{"stew"} = "\x{1F372}";
  $hash{"stopwatch"} = "\x{23F1}\x{FE0F}";
  $hash{"straight_ruler"} = "\x{1F4CF}";
  $hash{"strawberry"} = "\x{1F353}";
  $hash{"stuck_out_tongue_closed_eyes"} = "\x{1F61D}";
  $hash{"stuck_out_tongue_winking_eye"} = "\x{1F61C}";
  $hash{"sun_with_face"} = "\x{1F31E}";
  $hash{"sunflower"} = "\x{1F33B}";
  $hash{"sunglasses"} = "\x{1F60E}";
  $hash{"sunrise"} = "\x{1F305}";
  $hash{"sunrise_over_mountains"} = "\x{1F304}";
  $hash{"surfer"} = "\x{1F3C4}";
  $hash{"sushi"} = "\x{1F363}";
  $hash{"suspension_railway"} = "\x{1F69F}";
  $hash{"sweat"} = "\x{1F613}";
  $hash{"sweat_drops"} = "\x{1F4A6}";
  $hash{"sweat_smile"} = "\x{1F605}";
  $hash{"sweet_potato"} = "\x{1F360}";
  $hash{"swimmer"} = "\x{1F3CA}";
  $hash{"symbols"} = "\x{1F523}";
  $hash{"syringe"} = "\x{1F489}";
  $hash{"tada"} = "\x{1F389}";
  $hash{"tanabata_tree"} = "\x{1F38B}";
  $hash{"tangerine"} = "\x{1F34A}";
  $hash{"taxi"} = "\x{1F695}";
  $hash{"tea"} = "\x{1F375}";
  $hash{"telephone_receiver"} = "\x{1F4DE}";
  $hash{"telescope"} = "\x{1F52D}";
  $hash{"tennis"} = "\x{1F3BE}";
  $hash{"thought_balloon"} = "\x{1F4AD}";
  $hash{"thumbsdown"} = "\x{1F44E}";
  $hash{"thumbsup"} = "\x{1F44D}";
  $hash{"ticket"} = "\x{1F3AB}";
  $hash{"tiger"} = "\x{1F42F}";
  $hash{"tiger2"} = "\x{1F405}";
  $hash{"timer_clock"} = "\x{23F2}\x{FE0F}";
  $hash{"tired_face"} = "\x{1F62B}";
  $hash{"toilet"} = "\x{1F6BD}";
  $hash{"tokyo_tower"} = "\x{1F5FC}";
  $hash{"tomato"} = "\x{1F345}";
  $hash{"tongue"} = "\x{1F445}";
  $hash{"top"} = "\x{1F51D}";
  $hash{"tophat"} = "\x{1F3A9}";
  $hash{"tractor"} = "\x{1F69C}";
  $hash{"traffic_light"} = "\x{1F6A5}";
  $hash{"train"} = "\x{1F68B}";
  $hash{"train2"} = "\x{1F686}";
  $hash{"tram"} = "\x{1F68A}";
  $hash{"triangular_flag_on_post"} = "\x{1F6A9}";
  $hash{"triangular_ruler"} = "\x{1F4D0}";
  $hash{"trident"} = "\x{1F531}";
  $hash{"triumph"} = "\x{1F624}";
  $hash{"trolleybus"} = "\x{1F68E}";
  $hash{"trophy"} = "\x{1F3C6}";
  $hash{"tropical_drink"} = "\x{1F379}";
  $hash{"tropical_fish"} = "\x{1F420}";
  $hash{"truck"} = "\x{1F69A}";
  $hash{"trumpet"} = "\x{1F3BA}";
  $hash{"tshirt"} = "\x{1F455}";
  $hash{"tulip"} = "\x{1F337}";
  $hash{"turtle"} = "\x{1F422}";
  $hash{"tv"} = "\x{1F4FA}";
  $hash{"twisted_rightwards_arrows"} = "\x{1F500}";
  $hash{"two_hearts"} = "\x{1F495}";
  $hash{"two_men_holding_hands"} = "\x{1F46C}";
  $hash{"two_women_holding_hands"} = "\x{1F46D}";
  $hash{"u5272"} = "\x{1F239}";
  $hash{"u5408"} = "\x{1F234}";
  $hash{"u55b6"} = "\x{1F23A}";
  $hash{"u6708"} = "\x{1F237}\x{FE0F}";
  $hash{"u6709"} = "\x{1F236}";
  $hash{"u6e80"} = "\x{1F235}";
  $hash{"u7533"} = "\x{1F238}";
  $hash{"u7981"} = "\x{1F232}";
  $hash{"u7a7a"} = "\x{1F233}";
  $hash{"uk"} = "\x{1F1EC}\x{1F1E7}";
  $hash{"unamused"} = "\x{1F612}";
  $hash{"underage"} = "\x{1F51E}";
  $hash{"unlock"} = "\x{1F513}";
  $hash{"up"} = "\x{1F199}";
  $hash{"us"} = "\x{1F1FA}\x{1F1F8}";
  $hash{"vertical_traffic_light"} = "\x{1F6A6}";
  $hash{"vhs"} = "\x{1F4FC}";
  $hash{"vibration_mode"} = "\x{1F4F3}";
  $hash{"video_camera"} = "\x{1F4F9}";
  $hash{"video_game"} = "\x{1F3AE}";
  $hash{"violin"} = "\x{1F3BB}";
  $hash{"volcano"} = "\x{1F30B}";
  $hash{"vs"} = "\x{1F19A}";
  $hash{"walking"} = "\x{1F6B6}";
  $hash{"waning_crescent_moon"} = "\x{1F318}";
  $hash{"waning_gibbous_moon"} = "\x{1F316}";
  $hash{"water_buffalo"} = "\x{1F403}";
  $hash{"watermelon"} = "\x{1F349}";
  $hash{"wave"} = "\x{1F44B}";
  $hash{"waxing_crescent_moon"} = "\x{1F312}";
  $hash{"waxing_gibbous_moon"} = "\x{1F314}";
  $hash{"wc"} = "\x{1F6BE}";
  $hash{"weary"} = "\x{1F629}";
  $hash{"wedding"} = "\x{1F492}";
  $hash{"whale"} = "\x{1F433}";
  $hash{"whale2"} = "\x{1F40B}";
  $hash{"white_check_mark"} = "\x{2705}";
  $hash{"white_flower"} = "\x{1F4AE}";
  $hash{"white_square_button"} = "\x{1F533}";
  $hash{"wind_chime"} = "\x{1F390}";
  $hash{"wine_glass"} = "\x{1F377}";
  $hash{"wink"} = "\x{1F609}";
  $hash{"wolf"} = "\x{1F43A}";
  $hash{"woman"} = "\x{1F469}";
  $hash{"woman-biking"} = "\x{1F6B4}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-bowing"} = "\x{1F647}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-boy"} = "\x{1F469}\x{200D}\x{1F466}";
  $hash{"woman-boy-boy"} = "\x{1F469}\x{200D}\x{1F466}\x{200D}\x{1F466}";
  $hash{"woman-frowning"} = "\x{1F64D}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-gesturing-no"} = "\x{1F645}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-gesturing-ok"} = "\x{1F646}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-getting-haircut"} = "\x{1F487}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-getting-massage"} = "\x{1F486}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-girl"} = "\x{1F469}\x{200D}\x{1F467}";
  $hash{"woman-girl-boy"} = "\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F466}";
  $hash{"woman-girl-girl"} = "\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F467}";
  $hash{"woman-heart-man"} = "\x{1F469}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F468}";
  $hash{"woman-heart-woman"} = "\x{1F469}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F469}";
  $hash{"woman-kiss-man"} = "\x{1F469}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F48B}\x{200D}\x{1F468}";
  $hash{"woman-kiss-woman"} = "\x{1F469}\x{200D}\x{2764}\x{FE0F}\x{200D}\x{1F48B}\x{200D}\x{1F469}";
  $hash{"woman-mountain-biking"} = "\x{1F6B5}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-pouting"} = "\x{1F64E}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-raising-hand"} = "\x{1F64B}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-rowing-boat"} = "\x{1F6A3}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-running"} = "\x{1F3C3}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-surfing"} = "\x{1F3C4}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-swimming"} = "\x{1F3CA}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-tipping-hand"} = "\x{1F481}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-walking"} = "\x{1F6B6}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-wearing-turban"} = "\x{1F473}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-woman-boy"} = "\x{1F469}\x{200D}\x{1F469}\x{200D}\x{1F466}";
  $hash{"woman-woman-boy-boy"} = "\x{1F469}\x{200D}\x{1F469}\x{200D}\x{1F466}\x{200D}\x{1F466}";
  $hash{"woman-woman-girl"} = "\x{1F469}\x{200D}\x{1F469}\x{200D}\x{1F467}";
  $hash{"woman-woman-girl-boy"} = "\x{1F469}\x{200D}\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F466}";
  $hash{"woman-woman-girl-girl"} = "\x{1F469}\x{200D}\x{1F469}\x{200D}\x{1F467}\x{200D}\x{1F467}";
  $hash{"woman_and_man_holding_hands"} = "\x{1F46B}";
  $hash{"womans_clothes"} = "\x{1F45A}";
  $hash{"womans_hat"} = "\x{1F452}";
  $hash{"women-with-bunny-ears-partying"} = "\x{1F46F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"women_holding_hands"} = "\x{1F46D}";
  $hash{"womens"} = "\x{1F6BA}";
  $hash{"wrench"} = "\x{1F527}";
  $hash{"x"} = "\x{274C}";
  $hash{"yellow_heart"} = "\x{1F49B}";
  $hash{"yen"} = "\x{1F4B4}";
  $hash{"yum"} = "\x{1F60B}";
  $hash{"zzz"} = "\x{1F4A4}";
}
if ($] >= 5.016 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"anguished"} = "\x{1F627}";
  $hash{"confused"} = "\x{1F615}";
  $hash{"expressionless"} = "\x{1F611}";
  $hash{"frowning"} = "\x{1F626}";
  $hash{"grimacing"} = "\x{1F62C}";
  $hash{"grinning"} = "\x{1F600}";
  $hash{"hushed"} = "\x{1F62F}";
  $hash{"kissing"} = "\x{1F617}";
  $hash{"kissing_smiling_eyes"} = "\x{1F619}";
  $hash{"open_mouth"} = "\x{1F62E}";
  $hash{"sleeping"} = "\x{1F634}";
  $hash{"stuck_out_tongue"} = "\x{1F61B}";
  $hash{"worried"} = "\x{1F61F}";
}
if ($] >= 5.022 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"admission_tickets"} = "\x{1F39F}\x{FE0F}";
  $hash{"airplane_arriving"} = "\x{1F6EC}";
  $hash{"airplane_departure"} = "\x{1F6EB}";
  $hash{"ballot_box_with_ballot"} = "\x{1F5F3}\x{FE0F}";
  $hash{"barely_sunny"} = "\x{1F325}\x{FE0F}";
  $hash{"beach_with_umbrella"} = "\x{1F3D6}\x{FE0F}";
  $hash{"bed"} = "\x{1F6CF}\x{FE0F}";
  $hash{"bellhop_bell"} = "\x{1F6CE}\x{FE0F}";
  $hash{"black_circle_for_record"} = "\x{23FA}\x{FE0F}";
  $hash{"black_square_for_stop"} = "\x{23F9}\x{FE0F}";
  $hash{"building_construction"} = "\x{1F3D7}\x{FE0F}";
  $hash{"camera_with_flash"} = "\x{1F4F8}";
  $hash{"camping"} = "\x{1F3D5}\x{FE0F}";
  $hash{"candle"} = "\x{1F56F}\x{FE0F}";
  $hash{"card_file_box"} = "\x{1F5C3}\x{FE0F}";
  $hash{"card_index_dividers"} = "\x{1F5C2}\x{FE0F}";
  $hash{"chipmunk"} = "\x{1F43F}\x{FE0F}";
  $hash{"cityscape"} = "\x{1F3D9}\x{FE0F}";
  $hash{"classical_building"} = "\x{1F3DB}\x{FE0F}";
  $hash{"compression"} = "\x{1F5DC}\x{FE0F}";
  $hash{"control_knobs"} = "\x{1F39B}\x{FE0F}";
  $hash{"couch_and_lamp"} = "\x{1F6CB}\x{FE0F}";
  $hash{"dagger_knife"} = "\x{1F5E1}\x{FE0F}";
  $hash{"dark_sunglasses"} = "\x{1F576}\x{FE0F}";
  $hash{"derelict_house_building"} = "\x{1F3DA}\x{FE0F}";
  $hash{"desert"} = "\x{1F3DC}\x{FE0F}";
  $hash{"desert_island"} = "\x{1F3DD}\x{FE0F}";
  $hash{"desktop_computer"} = "\x{1F5A5}\x{FE0F}";
  $hash{"double_vertical_bar"} = "\x{23F8}\x{FE0F}";
  $hash{"dove_of_peace"} = "\x{1F54A}\x{FE0F}";
  $hash{"eye"} = "\x{1F441}\x{FE0F}";
  $hash{"eye-in-speech-bubble"} = "\x{1F441}\x{FE0F}\x{200D}\x{1F5E8}\x{FE0F}";
  $hash{"female-detective"} = "\x{1F575}\x{FE0F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"file_cabinet"} = "\x{1F5C4}\x{FE0F}";
  $hash{"film_frames"} = "\x{1F39E}\x{FE0F}";
  $hash{"film_projector"} = "\x{1F4FD}\x{FE0F}";
  $hash{"flag-england"} = "\x{1F3F4}\x{E0067}\x{E0062}\x{E0065}\x{E006E}\x{E0067}\x{E007F}";
  $hash{"flag-scotland"} = "\x{1F3F4}\x{E0067}\x{E0062}\x{E0073}\x{E0063}\x{E0074}\x{E007F}";
  $hash{"flag-wales"} = "\x{1F3F4}\x{E0067}\x{E0062}\x{E0077}\x{E006C}\x{E0073}\x{E007F}";
  $hash{"fog"} = "\x{1F32B}\x{FE0F}";
  $hash{"frame_with_picture"} = "\x{1F5BC}\x{FE0F}";
  $hash{"golfer"} = "\x{1F3CC}\x{FE0F}";
  $hash{"hammer_and_wrench"} = "\x{1F6E0}\x{FE0F}";
  $hash{"hole"} = "\x{1F573}\x{FE0F}";
  $hash{"hot_pepper"} = "\x{1F336}\x{FE0F}";
  $hash{"house_buildings"} = "\x{1F3D8}\x{FE0F}";
  $hash{"joystick"} = "\x{1F579}\x{FE0F}";
  $hash{"knife_fork_plate"} = "\x{1F37D}\x{FE0F}";
  $hash{"label"} = "\x{1F3F7}\x{FE0F}";
  $hash{"left_speech_bubble"} = "\x{1F5E8}\x{FE0F}";
  $hash{"level_slider"} = "\x{1F39A}\x{FE0F}";
  $hash{"lightning"} = "\x{1F329}\x{FE0F}";
  $hash{"lightning_cloud"} = "\x{1F329}\x{FE0F}";
  $hash{"linked_paperclips"} = "\x{1F587}\x{FE0F}";
  $hash{"lower_left_ballpoint_pen"} = "\x{1F58A}\x{FE0F}";
  $hash{"lower_left_crayon"} = "\x{1F58D}\x{FE0F}";
  $hash{"lower_left_fountain_pen"} = "\x{1F58B}\x{FE0F}";
  $hash{"lower_left_paintbrush"} = "\x{1F58C}\x{FE0F}";
  $hash{"male-detective"} = "\x{1F575}\x{FE0F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-golfing"} = "\x{1F3CC}\x{FE0F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-lifting-weights"} = "\x{1F3CB}\x{FE0F}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_in_business_suit_levitating"} = "\x{1F574}\x{FE0F}";
  $hash{"mantelpiece_clock"} = "\x{1F570}\x{FE0F}";
  $hash{"medal"} = "\x{1F396}\x{FE0F}";
  $hash{"middle_finger"} = "\x{1F595}";
  $hash{"mostly_sunny"} = "\x{1F324}\x{FE0F}";
  $hash{"motor_boat"} = "\x{1F6E5}\x{FE0F}";
  $hash{"motorway"} = "\x{1F6E3}\x{FE0F}";
  $hash{"national_park"} = "\x{1F3DE}\x{FE0F}";
  $hash{"oil_drum"} = "\x{1F6E2}\x{FE0F}";
  $hash{"old_key"} = "\x{1F5DD}\x{FE0F}";
  $hash{"om_symbol"} = "\x{1F549}\x{FE0F}";
  $hash{"partly_sunny_rain"} = "\x{1F326}\x{FE0F}";
  $hash{"passenger_ship"} = "\x{1F6F3}\x{FE0F}";
  $hash{"printer"} = "\x{1F5A8}\x{FE0F}";
  $hash{"racing_car"} = "\x{1F3CE}\x{FE0F}";
  $hash{"racing_motorcycle"} = "\x{1F3CD}\x{FE0F}";
  $hash{"railway_track"} = "\x{1F6E4}\x{FE0F}";
  $hash{"rain_cloud"} = "\x{1F327}\x{FE0F}";
  $hash{"rainbow-flag"} = "\x{1F3F3}\x{FE0F}\x{200D}\x{1F308}";
  $hash{"raised_hand_with_fingers_splayed"} = "\x{1F590}\x{FE0F}";
  $hash{"reminder_ribbon"} = "\x{1F397}\x{FE0F}";
  $hash{"reversed_hand_with_middle_finger_extended"} = "\x{1F595}";
  $hash{"right_anger_bubble"} = "\x{1F5EF}\x{FE0F}";
  $hash{"rolled_up_newspaper"} = "\x{1F5DE}\x{FE0F}";
  $hash{"rosette"} = "\x{1F3F5}\x{FE0F}";
  $hash{"satellite"} = "\x{1F6F0}\x{FE0F}";
  $hash{"shield"} = "\x{1F6E1}\x{FE0F}";
  $hash{"shopping_bags"} = "\x{1F6CD}\x{FE0F}";
  $hash{"sleeping_accommodation"} = "\x{1F6CC}";
  $hash{"sleuth_or_spy"} = "\x{1F575}\x{FE0F}";
  $hash{"slightly_frowning_face"} = "\x{1F641}";
  $hash{"slightly_smiling_face"} = "\x{1F642}";
  $hash{"small_airplane"} = "\x{1F6E9}\x{FE0F}";
  $hash{"snow_capped_mountain"} = "\x{1F3D4}\x{FE0F}";
  $hash{"snow_cloud"} = "\x{1F328}\x{FE0F}";
  $hash{"speaking_head_in_silhouette"} = "\x{1F5E3}\x{FE0F}";
  $hash{"spider"} = "\x{1F577}\x{FE0F}";
  $hash{"spider_web"} = "\x{1F578}\x{FE0F}";
  $hash{"spiral_calendar_pad"} = "\x{1F5D3}\x{FE0F}";
  $hash{"spiral_note_pad"} = "\x{1F5D2}\x{FE0F}";
  $hash{"spock-hand"} = "\x{1F596}";
  $hash{"sports_medal"} = "\x{1F3C5}";
  $hash{"stadium"} = "\x{1F3DF}\x{FE0F}";
  $hash{"studio_microphone"} = "\x{1F399}\x{FE0F}";
  $hash{"sun_behind_cloud"} = "\x{1F325}\x{FE0F}";
  $hash{"sun_behind_rain_cloud"} = "\x{1F326}\x{FE0F}";
  $hash{"sun_small_cloud"} = "\x{1F324}\x{FE0F}";
  $hash{"thermometer"} = "\x{1F321}\x{FE0F}";
  $hash{"three_button_mouse"} = "\x{1F5B1}\x{FE0F}";
  $hash{"tornado"} = "\x{1F32A}\x{FE0F}";
  $hash{"tornado_cloud"} = "\x{1F32A}\x{FE0F}";
  $hash{"trackball"} = "\x{1F5B2}\x{FE0F}";
  $hash{"wastebasket"} = "\x{1F5D1}\x{FE0F}";
  $hash{"waving_black_flag"} = "\x{1F3F4}";
  $hash{"waving_white_flag"} = "\x{1F3F3}\x{FE0F}";
  $hash{"weight_lifter"} = "\x{1F3CB}\x{FE0F}";
  $hash{"wind_blowing_face"} = "\x{1F32C}\x{FE0F}";
  $hash{"woman-golfing"} = "\x{1F3CC}\x{FE0F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-lifting-weights"} = "\x{1F3CB}\x{FE0F}\x{200D}\x{2640}\x{FE0F}";
  $hash{"world_map"} = "\x{1F5FA}\x{FE0F}";
}
if ($] >= 5.024 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"amphora"} = "\x{1F3FA}";
  $hash{"badminton_racquet_and_shuttlecock"} = "\x{1F3F8}";
  $hash{"bow_and_arrow"} = "\x{1F3F9}";
  $hash{"burrito"} = "\x{1F32F}";
  $hash{"champagne"} = "\x{1F37E}";
  $hash{"cheese_wedge"} = "\x{1F9C0}";
  $hash{"crab"} = "\x{1F980}";
  $hash{"cricket_bat_and_ball"} = "\x{1F3CF}";
  $hash{"face_with_head_bandage"} = "\x{1F915}";
  $hash{"face_with_rolling_eyes"} = "\x{1F644}";
  $hash{"face_with_thermometer"} = "\x{1F912}";
  $hash{"field_hockey_stick_and_ball"} = "\x{1F3D1}";
  $hash{"hotdog"} = "\x{1F32D}";
  $hash{"hugging_face"} = "\x{1F917}";
  $hash{"ice_hockey_stick_and_puck"} = "\x{1F3D2}";
  $hash{"kaaba"} = "\x{1F54B}";
  $hash{"lion_face"} = "\x{1F981}";
  $hash{"menorah_with_nine_branches"} = "\x{1F54E}";
  $hash{"money_mouth_face"} = "\x{1F911}";
  $hash{"mosque"} = "\x{1F54C}";
  $hash{"nerd_face"} = "\x{1F913}";
  $hash{"place_of_worship"} = "\x{1F6D0}";
  $hash{"popcorn"} = "\x{1F37F}";
  $hash{"prayer_beads"} = "\x{1F4FF}";
  $hash{"robot_face"} = "\x{1F916}";
  $hash{"scorpion"} = "\x{1F982}";
  $hash{"sign_of_the_horns"} = "\x{1F918}";
  $hash{"skin-tone-2"} = "\x{1F3FB}";
  $hash{"skin-tone-3"} = "\x{1F3FC}";
  $hash{"skin-tone-4"} = "\x{1F3FD}";
  $hash{"skin-tone-5"} = "\x{1F3FE}";
  $hash{"skin-tone-6"} = "\x{1F3FF}";
  $hash{"synagogue"} = "\x{1F54D}";
  $hash{"table_tennis_paddle_and_ball"} = "\x{1F3D3}";
  $hash{"taco"} = "\x{1F32E}";
  $hash{"the_horns"} = "\x{1F918}";
  $hash{"thinking_face"} = "\x{1F914}";
  $hash{"turkey"} = "\x{1F983}";
  $hash{"unicorn_face"} = "\x{1F984}";
  $hash{"upside_down_face"} = "\x{1F643}";
  $hash{"volleyball"} = "\x{1F3D0}";
  $hash{"zipper_mouth_face"} = "\x{1F910}";
}
if ($] >= 5.026 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"avocado"} = "\x{1F951}";
  $hash{"bacon"} = "\x{1F953}";
  $hash{"baguette_bread"} = "\x{1F956}";
  $hash{"bat"} = "\x{1F987}";
  $hash{"black_heart"} = "\x{1F5A4}";
  $hash{"boxing_glove"} = "\x{1F94A}";
  $hash{"butterfly"} = "\x{1F98B}";
  $hash{"call_me_hand"} = "\x{1F919}";
  $hash{"canoe"} = "\x{1F6F6}";
  $hash{"carrot"} = "\x{1F955}";
  $hash{"clinking_glasses"} = "\x{1F942}";
  $hash{"clown_face"} = "\x{1F921}";
  $hash{"croissant"} = "\x{1F950}";
  $hash{"crossed_fingers"} = "\x{1F91E}";
  $hash{"cucumber"} = "\x{1F952}";
  $hash{"deer"} = "\x{1F98C}";
  $hash{"drooling_face"} = "\x{1F924}";
  $hash{"drum_with_drumsticks"} = "\x{1F941}";
  $hash{"duck"} = "\x{1F986}";
  $hash{"eagle"} = "\x{1F985}";
  $hash{"egg"} = "\x{1F95A}";
  $hash{"face_palm"} = "\x{1F926}";
  $hash{"face_with_cowboy_hat"} = "\x{1F920}";
  $hash{"fencer"} = "\x{1F93A}";
  $hash{"first_place_medal"} = "\x{1F947}";
  $hash{"fox_face"} = "\x{1F98A}";
  $hash{"glass_of_milk"} = "\x{1F95B}";
  $hash{"goal_net"} = "\x{1F945}";
  $hash{"gorilla"} = "\x{1F98D}";
  $hash{"green_salad"} = "\x{1F957}";
  $hash{"hand_with_index_and_middle_fingers_crossed"} = "\x{1F91E}";
  $hash{"handball"} = "\x{1F93E}";
  $hash{"handshake"} = "\x{1F91D}";
  $hash{"juggling"} = "\x{1F939}";
  $hash{"kiwifruit"} = "\x{1F95D}";
  $hash{"left-facing_fist"} = "\x{1F91B}";
  $hash{"lizard"} = "\x{1F98E}";
  $hash{"lying_face"} = "\x{1F925}";
  $hash{"man-cartwheeling"} = "\x{1F938}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-facepalming"} = "\x{1F926}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-juggling"} = "\x{1F939}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-playing-handball"} = "\x{1F93E}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-playing-water-polo"} = "\x{1F93D}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-shrugging"} = "\x{1F937}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man-wrestling"} = "\x{1F93C}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_dancing"} = "\x{1F57A}";
  $hash{"martial_arts_uniform"} = "\x{1F94B}";
  $hash{"mother_christmas"} = "\x{1F936}";
  $hash{"motor_scooter"} = "\x{1F6F5}";
  $hash{"mrs_claus"} = "\x{1F936}";
  $hash{"nauseated_face"} = "\x{1F922}";
  $hash{"octagonal_sign"} = "\x{1F6D1}";
  $hash{"owl"} = "\x{1F989}";
  $hash{"pancakes"} = "\x{1F95E}";
  $hash{"peanuts"} = "\x{1F95C}";
  $hash{"person_doing_cartwheel"} = "\x{1F938}";
  $hash{"person_in_tuxedo"} = "\x{1F935}";
  $hash{"potato"} = "\x{1F954}";
  $hash{"pregnant_woman"} = "\x{1F930}";
  $hash{"prince"} = "\x{1F934}";
  $hash{"raised_back_of_hand"} = "\x{1F91A}";
  $hash{"rhinoceros"} = "\x{1F98F}";
  $hash{"right-facing_fist"} = "\x{1F91C}";
  $hash{"rolling_on_the_floor_laughing"} = "\x{1F923}";
  $hash{"scooter"} = "\x{1F6F4}";
  $hash{"second_place_medal"} = "\x{1F948}";
  $hash{"selfie"} = "\x{1F933}";
  $hash{"shallow_pan_of_food"} = "\x{1F958}";
  $hash{"shark"} = "\x{1F988}";
  $hash{"shopping_trolley"} = "\x{1F6D2}";
  $hash{"shrimp"} = "\x{1F990}";
  $hash{"shrug"} = "\x{1F937}";
  $hash{"sneezing_face"} = "\x{1F927}";
  $hash{"spoon"} = "\x{1F944}";
  $hash{"squid"} = "\x{1F991}";
  $hash{"stuffed_flatbread"} = "\x{1F959}";
  $hash{"third_place_medal"} = "\x{1F949}";
  $hash{"tumbler_glass"} = "\x{1F943}";
  $hash{"water_polo"} = "\x{1F93D}";
  $hash{"wilted_flower"} = "\x{1F940}";
  $hash{"woman-cartwheeling"} = "\x{1F938}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-facepalming"} = "\x{1F926}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-juggling"} = "\x{1F939}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-playing-handball"} = "\x{1F93E}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-playing-water-polo"} = "\x{1F93D}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-shrugging"} = "\x{1F937}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman-wrestling"} = "\x{1F93C}\x{200D}\x{2640}\x{FE0F}";
  $hash{"wrestlers"} = "\x{1F93C}";
}
if ($] >= 5.028 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"adult"} = "\x{1F9D1}";
  $hash{"bearded_person"} = "\x{1F9D4}";
  $hash{"billed_cap"} = "\x{1F9E2}";
  $hash{"bowl_with_spoon"} = "\x{1F963}";
  $hash{"brain"} = "\x{1F9E0}";
  $hash{"breast-feeding"} = "\x{1F931}";
  $hash{"broccoli"} = "\x{1F966}";
  $hash{"canned_food"} = "\x{1F96B}";
  $hash{"child"} = "\x{1F9D2}";
  $hash{"chopsticks"} = "\x{1F962}";
  $hash{"coat"} = "\x{1F9E5}";
  $hash{"coconut"} = "\x{1F965}";
  $hash{"cricket"} = "\x{1F997}";
  $hash{"cup_with_straw"} = "\x{1F964}";
  $hash{"curling_stone"} = "\x{1F94C}";
  $hash{"cut_of_meat"} = "\x{1F969}";
  $hash{"dumpling"} = "\x{1F95F}";
  $hash{"elf"} = "\x{1F9DD}";
  $hash{"exploding_head"} = "\x{1F92F}";
  $hash{"face_vomiting"} = "\x{1F92E}";
  $hash{"face_with_finger_covering_closed_lips"} = "\x{1F92B}";
  $hash{"face_with_hand_over_mouth"} = "\x{1F92D}";
  $hash{"face_with_monocle"} = "\x{1F9D0}";
  $hash{"face_with_one_eyebrow_raised"} = "\x{1F928}";
  $hash{"face_with_open_mouth_vomiting"} = "\x{1F92E}";
  $hash{"face_with_raised_eyebrow"} = "\x{1F928}";
  $hash{"face_with_symbols_on_mouth"} = "\x{1F92C}";
  $hash{"fairy"} = "\x{1F9DA}";
  $hash{"female_elf"} = "\x{1F9DD}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_fairy"} = "\x{1F9DA}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_genie"} = "\x{1F9DE}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_mage"} = "\x{1F9D9}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_vampire"} = "\x{1F9DB}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_zombie"} = "\x{1F9DF}\x{200D}\x{2640}\x{FE0F}";
  $hash{"flying_saucer"} = "\x{1F6F8}";
  $hash{"fortune_cookie"} = "\x{1F960}";
  $hash{"genie"} = "\x{1F9DE}";
  $hash{"giraffe_face"} = "\x{1F992}";
  $hash{"gloves"} = "\x{1F9E4}";
  $hash{"grinning_face_with_one_large_and_one_small_eye"} = "\x{1F92A}";
  $hash{"grinning_face_with_star_eyes"} = "\x{1F929}";
  $hash{"hedgehog"} = "\x{1F994}";
  $hash{"i_love_you_hand_sign"} = "\x{1F91F}";
  $hash{"mage"} = "\x{1F9D9}";
  $hash{"male_elf"} = "\x{1F9DD}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_fairy"} = "\x{1F9DA}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_genie"} = "\x{1F9DE}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_mage"} = "\x{1F9D9}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_vampire"} = "\x{1F9DB}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_zombie"} = "\x{1F9DF}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_climbing"} = "\x{1F9D7}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_in_lotus_position"} = "\x{1F9D8}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_in_steamy_room"} = "\x{1F9D6}\x{200D}\x{2642}\x{FE0F}";
  $hash{"mermaid"} = "\x{1F9DC}\x{200D}\x{2640}\x{FE0F}";
  $hash{"merman"} = "\x{1F9DC}\x{200D}\x{2642}\x{FE0F}";
  $hash{"merperson"} = "\x{1F9DC}";
  $hash{"older_adult"} = "\x{1F9D3}";
  $hash{"orange_heart"} = "\x{1F9E1}";
  $hash{"palms_up_together"} = "\x{1F932}";
  $hash{"person_climbing"} = "\x{1F9D7}";
  $hash{"person_in_lotus_position"} = "\x{1F9D8}";
  $hash{"person_in_steamy_room"} = "\x{1F9D6}";
  $hash{"person_with_headscarf"} = "\x{1F9D5}";
  $hash{"pie"} = "\x{1F967}";
  $hash{"pretzel"} = "\x{1F968}";
  $hash{"sandwich"} = "\x{1F96A}";
  $hash{"sauropod"} = "\x{1F995}";
  $hash{"scarf"} = "\x{1F9E3}";
  $hash{"serious_face_with_symbols_covering_mouth"} = "\x{1F92C}";
  $hash{"shocked_face_with_exploding_head"} = "\x{1F92F}";
  $hash{"shushing_face"} = "\x{1F92B}";
  $hash{"sled"} = "\x{1F6F7}";
  $hash{"smiling_face_with_smiling_eyes_and_hand_covering_mouth"} = "\x{1F92D}";
  $hash{"socks"} = "\x{1F9E6}";
  $hash{"star-struck"} = "\x{1F929}";
  $hash{"t-rex"} = "\x{1F996}";
  $hash{"takeout_box"} = "\x{1F961}";
  $hash{"vampire"} = "\x{1F9DB}";
  $hash{"woman_climbing"} = "\x{1F9D7}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman_in_lotus_position"} = "\x{1F9D8}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman_in_steamy_room"} = "\x{1F9D6}\x{200D}\x{2640}\x{FE0F}";
  $hash{"zany_face"} = "\x{1F92A}";
  $hash{"zebra_face"} = "\x{1F993}";
  $hash{"zombie"} = "\x{1F9DF}";
}
if ($] >= 5.030 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"abacus"} = "\x{1F9EE}";
  $hash{"adhesive_bandage"} = "\x{1FA79}";
  $hash{"artist"} = "\x{1F9D1}\x{200D}\x{1F3A8}";
  $hash{"astronaut"} = "\x{1F9D1}\x{200D}\x{1F680}";
  $hash{"auto_rickshaw"} = "\x{1F6FA}";
  $hash{"axe"} = "\x{1FA93}";
  $hash{"badger"} = "\x{1F9A1}";
  $hash{"bagel"} = "\x{1F96F}";
  $hash{"bald_man"} = "\x{1F468}\x{200D}\x{1F9B2}";
  $hash{"bald_person"} = "\x{1F9D1}\x{200D}\x{1F9B2}";
  $hash{"bald_woman"} = "\x{1F469}\x{200D}\x{1F9B2}";
  $hash{"ballet_shoes"} = "\x{1FA70}";
  $hash{"banjo"} = "\x{1FA95}";
  $hash{"basket"} = "\x{1F9FA}";
  $hash{"beverage_box"} = "\x{1F9C3}";
  $hash{"bone"} = "\x{1F9B4}";
  $hash{"bricks"} = "\x{1F9F1}";
  $hash{"briefs"} = "\x{1FA72}";
  $hash{"broom"} = "\x{1F9F9}";
  $hash{"brown_heart"} = "\x{1F90E}";
  $hash{"butter"} = "\x{1F9C8}";
  $hash{"chair"} = "\x{1FA91}";
  $hash{"chess_pawn"} = "\x{265F}\x{FE0F}";
  $hash{"cold_face"} = "\x{1F976}";
  $hash{"compass"} = "\x{1F9ED}";
  $hash{"cook"} = "\x{1F9D1}\x{200D}\x{1F373}";
  $hash{"cupcake"} = "\x{1F9C1}";
  $hash{"curly_haired_man"} = "\x{1F468}\x{200D}\x{1F9B1}";
  $hash{"curly_haired_person"} = "\x{1F9D1}\x{200D}\x{1F9B1}";
  $hash{"curly_haired_woman"} = "\x{1F469}\x{200D}\x{1F9B1}";
  $hash{"deaf_man"} = "\x{1F9CF}\x{200D}\x{2642}\x{FE0F}";
  $hash{"deaf_person"} = "\x{1F9CF}";
  $hash{"deaf_woman"} = "\x{1F9CF}\x{200D}\x{2640}\x{FE0F}";
  $hash{"diving_mask"} = "\x{1F93F}";
  $hash{"diya_lamp"} = "\x{1FA94}";
  $hash{"dna"} = "\x{1F9EC}";
  $hash{"drop_of_blood"} = "\x{1FA78}";
  $hash{"ear_with_hearing_aid"} = "\x{1F9BB}";
  $hash{"factory_worker"} = "\x{1F9D1}\x{200D}\x{1F3ED}";
  $hash{"falafel"} = "\x{1F9C6}";
  $hash{"farmer"} = "\x{1F9D1}\x{200D}\x{1F33E}";
  $hash{"female_superhero"} = "\x{1F9B8}\x{200D}\x{2640}\x{FE0F}";
  $hash{"female_supervillain"} = "\x{1F9B9}\x{200D}\x{2640}\x{FE0F}";
  $hash{"fire_extinguisher"} = "\x{1F9EF}";
  $hash{"firecracker"} = "\x{1F9E8}";
  $hash{"firefighter"} = "\x{1F9D1}\x{200D}\x{1F692}";
  $hash{"flamingo"} = "\x{1F9A9}";
  $hash{"flying_disc"} = "\x{1F94F}";
  $hash{"foot"} = "\x{1F9B6}";
  $hash{"garlic"} = "\x{1F9C4}";
  $hash{"goggles"} = "\x{1F97D}";
  $hash{"guide_dog"} = "\x{1F9AE}";
  $hash{"health_worker"} = "\x{1F9D1}\x{200D}\x{2695}\x{FE0F}";
  $hash{"hiking_boot"} = "\x{1F97E}";
  $hash{"hindu_temple"} = "\x{1F6D5}";
  $hash{"hippopotamus"} = "\x{1F99B}";
  $hash{"hot_face"} = "\x{1F975}";
  $hash{"ice_cube"} = "\x{1F9CA}";
  $hash{"infinity"} = "\x{267E}\x{FE0F}";
  $hash{"jigsaw"} = "\x{1F9E9}";
  $hash{"judge"} = "\x{1F9D1}\x{200D}\x{2696}\x{FE0F}";
  $hash{"kangaroo"} = "\x{1F998}";
  $hash{"kite"} = "\x{1FA81}";
  $hash{"kneeling_person"} = "\x{1F9CE}";
  $hash{"lab_coat"} = "\x{1F97C}";
  $hash{"lacrosse"} = "\x{1F94D}";
  $hash{"large_blue_square"} = "\x{1F7E6}";
  $hash{"large_brown_circle"} = "\x{1F7E4}";
  $hash{"large_brown_square"} = "\x{1F7EB}";
  $hash{"large_green_circle"} = "\x{1F7E2}";
  $hash{"large_green_square"} = "\x{1F7E9}";
  $hash{"large_orange_circle"} = "\x{1F7E0}";
  $hash{"large_orange_square"} = "\x{1F7E7}";
  $hash{"large_purple_circle"} = "\x{1F7E3}";
  $hash{"large_purple_square"} = "\x{1F7EA}";
  $hash{"large_red_square"} = "\x{1F7E5}";
  $hash{"large_yellow_circle"} = "\x{1F7E1}";
  $hash{"large_yellow_square"} = "\x{1F7E8}";
  $hash{"leafy_green"} = "\x{1F96C}";
  $hash{"leg"} = "\x{1F9B5}";
  $hash{"llama"} = "\x{1F999}";
  $hash{"lobster"} = "\x{1F99E}";
  $hash{"lotion_bottle"} = "\x{1F9F4}";
  $hash{"luggage"} = "\x{1F9F3}";
  $hash{"magnet"} = "\x{1F9F2}";
  $hash{"male_superhero"} = "\x{1F9B8}\x{200D}\x{2642}\x{FE0F}";
  $hash{"male_supervillain"} = "\x{1F9B9}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_in_manual_wheelchair"} = "\x{1F468}\x{200D}\x{1F9BD}";
  $hash{"man_in_motorized_wheelchair"} = "\x{1F468}\x{200D}\x{1F9BC}";
  $hash{"man_kneeling"} = "\x{1F9CE}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_standing"} = "\x{1F9CD}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_with_probing_cane"} = "\x{1F468}\x{200D}\x{1F9AF}";
  $hash{"mango"} = "\x{1F96D}";
  $hash{"manual_wheelchair"} = "\x{1F9BD}";
  $hash{"mate_drink"} = "\x{1F9C9}";
  $hash{"mechanic"} = "\x{1F9D1}\x{200D}\x{1F527}";
  $hash{"mechanical_arm"} = "\x{1F9BE}";
  $hash{"mechanical_leg"} = "\x{1F9BF}";
  $hash{"microbe"} = "\x{1F9A0}";
  $hash{"moon_cake"} = "\x{1F96E}";
  $hash{"mosquito"} = "\x{1F99F}";
  $hash{"motorized_wheelchair"} = "\x{1F9BC}";
  $hash{"nazar_amulet"} = "\x{1F9FF}";
  $hash{"office_worker"} = "\x{1F9D1}\x{200D}\x{1F4BC}";
  $hash{"one-piece_swimsuit"} = "\x{1FA71}";
  $hash{"onion"} = "\x{1F9C5}";
  $hash{"orangutan"} = "\x{1F9A7}";
  $hash{"otter"} = "\x{1F9A6}";
  $hash{"oyster"} = "\x{1F9AA}";
  $hash{"parachute"} = "\x{1FA82}";
  $hash{"parrot"} = "\x{1F99C}";
  $hash{"partying_face"} = "\x{1F973}";
  $hash{"peacock"} = "\x{1F99A}";
  $hash{"people_holding_hands"} = "\x{1F9D1}\x{200D}\x{1F91D}\x{200D}\x{1F9D1}";
  $hash{"person_in_manual_wheelchair"} = "\x{1F9D1}\x{200D}\x{1F9BD}";
  $hash{"person_in_motorized_wheelchair"} = "\x{1F9D1}\x{200D}\x{1F9BC}";
  $hash{"person_with_probing_cane"} = "\x{1F9D1}\x{200D}\x{1F9AF}";
  $hash{"petri_dish"} = "\x{1F9EB}";
  $hash{"pilot"} = "\x{1F9D1}\x{200D}\x{2708}\x{FE0F}";
  $hash{"pinching_hand"} = "\x{1F90F}";
  $hash{"pirate_flag"} = "\x{1F3F4}\x{200D}\x{2620}\x{FE0F}";
  $hash{"pleading_face"} = "\x{1F97A}";
  $hash{"probing_cane"} = "\x{1F9AF}";
  $hash{"raccoon"} = "\x{1F99D}";
  $hash{"razor"} = "\x{1FA92}";
  $hash{"receipt"} = "\x{1F9FE}";
  $hash{"red_envelope"} = "\x{1F9E7}";
  $hash{"red_haired_man"} = "\x{1F468}\x{200D}\x{1F9B0}";
  $hash{"red_haired_person"} = "\x{1F9D1}\x{200D}\x{1F9B0}";
  $hash{"red_haired_woman"} = "\x{1F469}\x{200D}\x{1F9B0}";
  $hash{"ringed_planet"} = "\x{1FA90}";
  $hash{"roll_of_paper"} = "\x{1F9FB}";
  $hash{"safety_pin"} = "\x{1F9F7}";
  $hash{"safety_vest"} = "\x{1F9BA}";
  $hash{"salt"} = "\x{1F9C2}";
  $hash{"sari"} = "\x{1F97B}";
  $hash{"scientist"} = "\x{1F9D1}\x{200D}\x{1F52C}";
  $hash{"service_dog"} = "\x{1F415}\x{200D}\x{1F9BA}";
  $hash{"shorts"} = "\x{1FA73}";
  $hash{"singer"} = "\x{1F9D1}\x{200D}\x{1F3A4}";
  $hash{"skateboard"} = "\x{1F6F9}";
  $hash{"skunk"} = "\x{1F9A8}";
  $hash{"sloth"} = "\x{1F9A5}";
  $hash{"smiling_face_with_3_hearts"} = "\x{1F970}";
  $hash{"soap"} = "\x{1F9FC}";
  $hash{"softball"} = "\x{1F94E}";
  $hash{"sponge"} = "\x{1F9FD}";
  $hash{"standing_person"} = "\x{1F9CD}";
  $hash{"stethoscope"} = "\x{1FA7A}";
  $hash{"student"} = "\x{1F9D1}\x{200D}\x{1F393}";
  $hash{"superhero"} = "\x{1F9B8}";
  $hash{"supervillain"} = "\x{1F9B9}";
  $hash{"swan"} = "\x{1F9A2}";
  $hash{"teacher"} = "\x{1F9D1}\x{200D}\x{1F3EB}";
  $hash{"technologist"} = "\x{1F9D1}\x{200D}\x{1F4BB}";
  $hash{"teddy_bear"} = "\x{1F9F8}";
  $hash{"test_tube"} = "\x{1F9EA}";
  $hash{"thread"} = "\x{1F9F5}";
  $hash{"toolbox"} = "\x{1F9F0}";
  $hash{"tooth"} = "\x{1F9B7}";
  $hash{"waffle"} = "\x{1F9C7}";
  $hash{"white_haired_man"} = "\x{1F468}\x{200D}\x{1F9B3}";
  $hash{"white_haired_person"} = "\x{1F9D1}\x{200D}\x{1F9B3}";
  $hash{"white_haired_woman"} = "\x{1F469}\x{200D}\x{1F9B3}";
  $hash{"white_heart"} = "\x{1F90D}";
  $hash{"woman_in_manual_wheelchair"} = "\x{1F469}\x{200D}\x{1F9BD}";
  $hash{"woman_in_motorized_wheelchair"} = "\x{1F469}\x{200D}\x{1F9BC}";
  $hash{"woman_kneeling"} = "\x{1F9CE}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman_standing"} = "\x{1F9CD}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman_with_probing_cane"} = "\x{1F469}\x{200D}\x{1F9AF}";
  $hash{"womans_flat_shoe"} = "\x{1F97F}";
  $hash{"woozy_face"} = "\x{1F974}";
  $hash{"yarn"} = "\x{1F9F6}";
  $hash{"yawning_face"} = "\x{1F971}";
  $hash{"yo-yo"} = "\x{1FA80}";
}
if ($] >= 5.032 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"accordion"} = "\x{1FA97}";
  $hash{"anatomical_heart"} = "\x{1FAC0}";
  $hash{"beaver"} = "\x{1F9AB}";
  $hash{"beetle"} = "\x{1FAB2}";
  $hash{"bell_pepper"} = "\x{1FAD1}";
  $hash{"bison"} = "\x{1F9AC}";
  $hash{"black_cat"} = "\x{1F408}\x{200D}\x{2B1B}";
  $hash{"blueberries"} = "\x{1FAD0}";
  $hash{"boomerang"} = "\x{1FA83}";
  $hash{"bubble_tea"} = "\x{1F9CB}";
  $hash{"bucket"} = "\x{1FAA3}";
  $hash{"carpentry_saw"} = "\x{1FA9A}";
  $hash{"cockroach"} = "\x{1FAB3}";
  $hash{"coin"} = "\x{1FA99}";
  $hash{"disguised_face"} = "\x{1F978}";
  $hash{"dodo"} = "\x{1F9A4}";
  $hash{"elevator"} = "\x{1F6D7}";
  $hash{"feather"} = "\x{1FAB6}";
  $hash{"flatbread"} = "\x{1FAD3}";
  $hash{"fly"} = "\x{1FAB0}";
  $hash{"fondue"} = "\x{1FAD5}";
  $hash{"headstone"} = "\x{1FAA6}";
  $hash{"hook"} = "\x{1FA9D}";
  $hash{"hut"} = "\x{1F6D6}";
  $hash{"knot"} = "\x{1FAA2}";
  $hash{"ladder"} = "\x{1FA9C}";
  $hash{"long_drum"} = "\x{1FA98}";
  $hash{"lungs"} = "\x{1FAC1}";
  $hash{"magic_wand"} = "\x{1FA84}";
  $hash{"mammoth"} = "\x{1F9A3}";
  $hash{"man_feeding_baby"} = "\x{1F468}\x{200D}\x{1F37C}";
  $hash{"man_in_tuxedo"} = "\x{1F935}\x{200D}\x{2642}\x{FE0F}";
  $hash{"man_with_veil"} = "\x{1F470}\x{200D}\x{2642}\x{FE0F}";
  $hash{"military_helmet"} = "\x{1FA96}";
  $hash{"mirror"} = "\x{1FA9E}";
  $hash{"mouse_trap"} = "\x{1FAA4}";
  $hash{"mx_claus"} = "\x{1F9D1}\x{200D}\x{1F384}";
  $hash{"nesting_dolls"} = "\x{1FA86}";
  $hash{"ninja"} = "\x{1F977}";
  $hash{"olive"} = "\x{1FAD2}";
  $hash{"people_hugging"} = "\x{1FAC2}";
  $hash{"person_feeding_baby"} = "\x{1F9D1}\x{200D}\x{1F37C}";
  $hash{"pickup_truck"} = "\x{1F6FB}";
  $hash{"pinata"} = "\x{1FA85}";
  $hash{"pinched_fingers"} = "\x{1F90C}";
  $hash{"placard"} = "\x{1FAA7}";
  $hash{"plunger"} = "\x{1FAA0}";
  $hash{"polar_bear"} = "\x{1F43B}\x{200D}\x{2744}\x{FE0F}";
  $hash{"potted_plant"} = "\x{1FAB4}";
  $hash{"rock"} = "\x{1FAA8}";
  $hash{"roller_skate"} = "\x{1F6FC}";
  $hash{"screwdriver"} = "\x{1FA9B}";
  $hash{"seal"} = "\x{1F9AD}";
  $hash{"sewing_needle"} = "\x{1FAA1}";
  $hash{"smiling_face_with_tear"} = "\x{1F972}";
  $hash{"tamale"} = "\x{1FAD4}";
  $hash{"teapot"} = "\x{1FAD6}";
  $hash{"thong_sandal"} = "\x{1FA74}";
  $hash{"toothbrush"} = "\x{1FAA5}";
  $hash{"transgender_flag"} = "\x{1F3F3}\x{FE0F}\x{200D}\x{26A7}\x{FE0F}";
  $hash{"transgender_symbol"} = "\x{26A7}\x{FE0F}";
  $hash{"window"} = "\x{1FA9F}";
  $hash{"woman_feeding_baby"} = "\x{1F469}\x{200D}\x{1F37C}";
  $hash{"woman_in_tuxedo"} = "\x{1F935}\x{200D}\x{2640}\x{FE0F}";
  $hash{"woman_with_veil"} = "\x{1F470}\x{200D}\x{2640}\x{FE0F}";
  $hash{"wood"} = "\x{1FAB5}";
  $hash{"worm"} = "\x{1FAB1}";
}
if ($] >= 5.036 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"beans"} = "\x{1FAD8}";
  $hash{"biting_lip"} = "\x{1FAE6}";
  $hash{"bubbles"} = "\x{1FAE7}";
  $hash{"coral"} = "\x{1FAB8}";
  $hash{"crutch"} = "\x{1FA7C}";
  $hash{"dotted_line_face"} = "\x{1FAE5}";
  $hash{"empty_nest"} = "\x{1FAB9}";
  $hash{"face_holding_back_tears"} = "\x{1F979}";
  $hash{"face_with_diagonal_mouth"} = "\x{1FAE4}";
  $hash{"face_with_open_eyes_and_hand_over_mouth"} = "\x{1FAE2}";
  $hash{"face_with_peeking_eye"} = "\x{1FAE3}";
  $hash{"hamsa"} = "\x{1FAAC}";
  $hash{"hand_with_index_finger_and_thumb_crossed"} = "\x{1FAF0}";
  $hash{"heart_hands"} = "\x{1FAF6}";
  $hash{"heavy_equals_sign"} = "\x{1F7F0}";
  $hash{"identification_card"} = "\x{1FAAA}";
  $hash{"index_pointing_at_the_viewer"} = "\x{1FAF5}";
  $hash{"jar"} = "\x{1FAD9}";
  $hash{"leftwards_hand"} = "\x{1FAF2}";
  $hash{"lotus"} = "\x{1FAB7}";
  $hash{"low_battery"} = "\x{1FAAB}";
  $hash{"melting_face"} = "\x{1FAE0}";
  $hash{"mirror_ball"} = "\x{1FAA9}";
  $hash{"nest_with_eggs"} = "\x{1FABA}";
  $hash{"palm_down_hand"} = "\x{1FAF3}";
  $hash{"palm_up_hand"} = "\x{1FAF4}";
  $hash{"person_with_crown"} = "\x{1FAC5}";
  $hash{"playground_slide"} = "\x{1F6DD}";
  $hash{"pouring_liquid"} = "\x{1FAD7}";
  $hash{"pregnant_man"} = "\x{1FAC3}";
  $hash{"pregnant_person"} = "\x{1FAC4}";
  $hash{"rightwards_hand"} = "\x{1FAF1}";
  $hash{"ring_buoy"} = "\x{1F6DF}";
  $hash{"saluting_face"} = "\x{1FAE1}";
  $hash{"troll"} = "\x{1F9CC}";
  $hash{"wheel"} = "\x{1F6DE}";
  $hash{"x-ray"} = "\x{1FA7B}";
}
if ($] >= 5.038 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"black_bird"} = "\x{1F426}\x{200D}\x{2B1B}";
  $hash{"donkey"} = "\x{1FACF}";
  $hash{"flute"} = "\x{1FA88}";
  $hash{"folding_hand_fan"} = "\x{1FAAD}";
  $hash{"ginger_root"} = "\x{1FADA}";
  $hash{"goose"} = "\x{1FABF}";
  $hash{"grey_heart"} = "\x{1FA76}";
  $hash{"hair_pick"} = "\x{1FAAE}";
  $hash{"hyacinth"} = "\x{1FABB}";
  $hash{"jellyfish"} = "\x{1FABC}";
  $hash{"khanda"} = "\x{1FAAF}";
  $hash{"leftwards_pushing_hand"} = "\x{1FAF7}";
  $hash{"light_blue_heart"} = "\x{1FA75}";
  $hash{"maracas"} = "\x{1FA87}";
  $hash{"moose"} = "\x{1FACE}";
  $hash{"pea_pod"} = "\x{1FADB}";
  $hash{"pink_heart"} = "\x{1FA77}";
  $hash{"rightwards_pushing_hand"} = "\x{1FAF8}";
  $hash{"shaking_face"} = "\x{1FAE8}";
  $hash{"wing"} = "\x{1FABD}";
  $hash{"wireless"} = "\x{1F6DC}";
}
if ($] >= 5.042 || ! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"broken_chain"} = "\x{26D3}\x{FE0F}\x{200D}\x{1F4A5}";
  $hash{"brown_mushroom"} = "\x{1F344}\x{200D}\x{1F7EB}";
  $hash{"face_with_bags_under_eyes"} = "\x{1FAE9}";
  $hash{"family_adult_adult_child"} = "\x{1F9D1}\x{200D}\x{1F9D1}\x{200D}\x{1F9D2}";
  $hash{"family_adult_adult_child_child"} = "\x{1F9D1}\x{200D}\x{1F9D1}\x{200D}\x{1F9D2}\x{200D}\x{1F9D2}";
  $hash{"family_adult_child"} = "\x{1F9D1}\x{200D}\x{1F9D2}";
  $hash{"family_adult_child_child"} = "\x{1F9D1}\x{200D}\x{1F9D2}\x{200D}\x{1F9D2}";
  $hash{"fingerprint"} = "\x{1FAC6}";
  $hash{"flag-sark"} = "\x{1F1E8}\x{1F1F6}";
  $hash{"harp"} = "\x{1FA89}";
  $hash{"head_shaking_horizontally"} = "\x{1F642}\x{200D}\x{2194}\x{FE0F}";
  $hash{"head_shaking_vertically"} = "\x{1F642}\x{200D}\x{2195}\x{FE0F}";
  $hash{"leafless_tree"} = "\x{1FABE}";
  $hash{"lime"} = "\x{1F34B}\x{200D}\x{1F7E9}";
  $hash{"man_in_manual_wheelchair_facing_right"} = "\x{1F468}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"man_in_motorized_wheelchair_facing_right"} = "\x{1F468}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"man_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"man_running_facing_right"} = "\x{1F3C3}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"man_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{2642}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"man_with_white_cane_facing_right"} = "\x{1F468}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_in_manual_wheelchair_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_in_motorized_wheelchair_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_running_facing_right"} = "\x{1F3C3}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"person_with_white_cane_facing_right"} = "\x{1F9D1}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"phoenix"} = "\x{1F426}\x{200D}\x{1F525}";
  $hash{"root_vegetable"} = "\x{1FADC}";
  $hash{"shovel"} = "\x{1FA8F}";
  $hash{"splatter"} = "\x{1FADF}";
  $hash{"woman_in_manual_wheelchair_facing_right"} = "\x{1F469}\x{200D}\x{1F9BD}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"woman_in_motorized_wheelchair_facing_right"} = "\x{1F469}\x{200D}\x{1F9BC}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"woman_kneeling_facing_right"} = "\x{1F9CE}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"woman_running_facing_right"} = "\x{1F3C3}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"woman_walking_facing_right"} = "\x{1F6B6}\x{200D}\x{2640}\x{FE0F}\x{200D}\x{27A1}\x{FE0F}";
  $hash{"woman_with_white_cane_facing_right"} = "\x{1F469}\x{200D}\x{1F9AF}\x{200D}\x{27A1}\x{FE0F}";
}
if (! $ENV{SLACKEMOJI_STRICT}) {
  $hash{"face_exhaling"} = "\x{1F62E}\x{200D}\x{1F4A8}";
  $hash{"face_in_clouds"} = "\x{1F636}\x{200D}\x{1F32B}\x{FE0F}";
  $hash{"face_with_spiral_eyes"} = "\x{1F635}\x{200D}\x{1F4AB}";
  $hash{"heart_on_fire"} = "\x{2764}\x{FE0F}\x{200D}\x{1F525}";
  $hash{"man_with_beard"} = "\x{1F9D4}\x{200D}\x{2642}\x{FE0F}";
  $hash{"mending_heart"} = "\x{2764}\x{FE0F}\x{200D}\x{1FA79}";
  $hash{"woman_with_beard"} = "\x{1F9D4}\x{200D}\x{2640}\x{FE0F}";
}
return \%hash;
